/***********************************************************
MISIZI MARSHLAND PROJECT PERFORMANCE EVALUATION 2022
************************************************************
OTHER INDICATORS AND DESCRIPTIVE ANALYSIS
************************************************************
Created by: Towfique Aziz, Sr. Advisor for M&E and Research
			towfique@tangointernational.com
			May 19, 2022
************************************************************/
************************************************************

cd "C:\Users\towfi\Dropbox (Tango International)\2021_UNHCR_IKEA_Rwanda\Quantitative\Data analysis"

use "Misizi_PE_11May2022_edited_working.dta", clear


**Project activity participation

/*
1	A.Access to land (received ready to use land from Misizi)
2	B.Agriculture production training (technics and management)
3	C.Livestock production (poultry/piggery) training on improved livestock practices and technologies
4	D.Livestock  production (poultry/piggery) support- start-up (inputs, such as, chicks, pigs, feedings, shelter)
5	E.Agriculture Inputs distribution (seeds, seedlings, fertilizer, tools (hoes) etc.)
6	F.Post-harvest support (warehouse, drying shed, milling support etc.)
7	G.Markets linkages (linking with buyers, market information etc.)
8	H.Joint cooperative membership and management (cooperative formation training, membership to cooperatives, cooperative management training etc.)
9	I.Women empowerment training to enhance  agriculture production
99	J.None
*/

tab1 AA103* // observations available up AA103_9

forvalues i=1/10{
gen AA103r_`i'=AA103_`i'
recode AA103r_`i' (99=10)
}

forvalues i=1/10{
gen proj_parti_`i'=0 if response==1
recode proj_parti_`i' (0=1) if AA103r_1==`i' | AA103r_2==`i' | AA103r_3==`i' | AA103r_4==`i' | AA103r_5==`i' | AA103r_6==`i' ///
							 | AA103r_7==`i' | AA103r_8==`i' | AA103r_9==`i' | AA103r_10==`i'
}

egen proj_parti_atl1_sum=rowtotal(proj_parti_1 - proj_parti_9) if response==1

gen proj_parti_atl1=proj_parti_atl1_sum
recode proj_parti_atl1 (0=0) (1/9=1)

tab proj_parti_atl1


svy: mean proj_parti_atl1, over(sample_type)
lincom [proj_parti_atl1]Refugee - [proj_parti_atl1]_subpop_2
svy: mean proj_parti_atl1

svy: mean proj_parti_1 proj_parti_2 proj_parti_3 proj_parti_4 proj_parti_5 proj_parti_6 proj_parti_7 proj_parti_8 proj_parti_9 proj_parti_10, over(sample_type)

svy: mean proj_parti_1 proj_parti_2 proj_parti_3 proj_parti_4 proj_parti_5 proj_parti_6 proj_parti_7 proj_parti_8 proj_parti_9 proj_parti_10

svy: mean proj_parti_atl1_sum, over(sample_type)
lincom [proj_parti_atl1_sum]Refugee - [proj_parti_atl1_sum]_subpop_2
svy: mean proj_parti_atl1_sum

forvalues i=1/10{
svy: mean proj_parti_`i', over(sample_type)
lincom [proj_parti_`i']Refugee - [proj_parti_`i']_subpop_2
}

*MODULE-B: HOUSEHOLD DIET DIVERSITY

/*Household food consumption score (FCS)

 •	The Food Consumption Score (FCS) is a composite score based on dietary diversity, food frequency, 
    and the relative nutritional importance of different food groups. To collect FCS data, a questionnaire 
	is used to ask respondents about the frequency of their households' consumption of 16 food groups over 
	the previous seven days. 
 •	Sixteen food groups regrouped into 9 main categories: Main staples, Pulses, Fruits, vegetables, 
    Meat/Fish/eggs, Milk, Sugar/honey, Oil and condiments. 
 •	To calculate the FCS, the consumption frequencies (number of days in last 7 days) are summed and 
    multiplied by the standardized food group weight (Main staples 2, Pulses 3, Fruit 1, vegetables 1, 
	Meat/Fish/Eggs 4, Milk/Milk products 4, Sugar/honey/products 0.5, Oil/fats/butter 0.5 and condiments 0), 
	and households are then be classified into three groups based on their weighted scores – poor (FCS 0-21), 
	borderline (FCS 21.5 to 35), or acceptable (FCS >35) - using the World Food Program's/EFSP indicator 
	guideline recommended cutoff points.
 •	Reference: FFP/ WFP/FAO Guideline*/
 
 	foreach x in A B C D E F G H I J K L{
	gen B101`x'r1=B101`x'1  
	recode B101`x'r1 (2=0)
	}

	foreach x in A B C D E F G H I J K L{
	tab1 B101`x'r1 
	}

tab1 B101AB1 B101AB2 B101AB3

gen B101A2r=B101A2
recode B101A2r(.=0)
gen B101B2r=B101B2
recode B101B2r(.=0)

gen B101AB3r=B101AB3
recode B101AB3r (0=2) if sample_id==20
recode B101AB3r (3=0) if sample_id==21
recode B101AB3r (3=0) if sample_id==40
recode B101AB3r (0=2) if sample_id==47
recode B101AB3r (3=2) if sample_id==51
recode B101AB3r (0=3) if sample_id==65
recode B101AB3r (1=0) if sample_id==74
recode B101AB3r (0=2) if sample_id==89
recode B101AB3r (1=0) if sample_id==94
recode B101AB3r (0=1) if sample_id==98
recode B101AB3r (6=0) if sample_id==101
recode B101AB3r (0=2) if sample_id==113
recode B101AB3r (1=4) if sample_id==131
recode B101AB3r (0=3) if sample_id==139
recode B101AB3r (2=3) if sample_id==151
recode B101AB3r (0=3) if sample_id==153
recode B101AB3r (0=2) if sample_id==154
recode B101AB3r (2=5) if sample_id==165
recode B101AB3r (0=2) if sample_id==181
recode B101AB3r (0=1) if sample_id==184
recode B101AB3r (4=0) if sample_id==188
recode B101AB3r (0=3) if sample_id==192
recode B101AB3r (0=1) if sample_id==205
recode B101AB3r (0=2) if sample_id==220
recode B101AB3r (0=7) if sample_id==232
recode B101AB3r (3=0) if sample_id==235
recode B101AB3r (1=2) if sample_id==255
recode B101AB3r (0=3) if sample_id==256
recode B101AB3r (2=4) if sample_id==258
recode B101AB3r (0=1) if sample_id==262
recode B101AB3r (3=0) if sample_id==293
recode B101AB3r (4=0) if sample_id==315
recode B101AB3r (4=0) if sample_id==323
recode B101AB3r (3=0) if sample_id==330
recode B101AB3r (3=0) if sample_id==338
recode B101AB3r (0=1) if sample_id==349
recode B101AB3r (1=2) if sample_id==353
recode B101AB3r (1=2) if sample_id==354
recode B101AB3r (2=3) if sample_id==357
recode B101AB3r (2=5) if sample_id==359
recode B101AB3r (4=5) if sample_id==364
recode B101AB3r (3=0) if sample_id==369
recode B101AB3r (7=1) if sample_id==380
recode B101AB3r (6=7) if sample_id==383
recode B101AB3r (0=7) if sample_id==387
recode B101AB3r (2=3) if sample_id==399


gen cereals_tubers=.
replace cereals_tubers=max(B101A2r,B101B2r) if B101AB3r==B101A2r | B101AB3r==B101B2r
replace cereals_tubers=max(B101A2r,B101B2r)+(min(B101A2r,B101B2r)-B101AB3r) if (B101AB3r~=B101A2r) & (B101AB3r~=B101B2r) & B101AB3r~=0  
replace cereals_tubers=B101A2r+B101B2r if B101AB3r==0
recode cereals_tubers (0=.) 

gen B101C2r=B101C2
recode B101C2r (.=0)
gen B101D2r=B101D2
recode B101D2r (.=0)

gen B101cd3r=B101cd3
recode B101cd3r (2=3) if sample_id==15
recode B101cd3r (5=2) if sample_id==19
recode B101cd3r (5=0) if sample_id==21
recode B101cd3r (0=4) if sample_id==32
recode B101cd3r (0=2) if sample_id==50
recode B101cd3r (1=0) if sample_id==73
recode B101cd3r (2=0) if sample_id==77
recode B101cd3r (2=0) if sample_id==79
recode B101cd3r (2=0) if sample_id==104
recode B101cd3r (1=0) if sample_id==107
recode B101cd3r (2=0) if sample_id==128
recode B101cd3r (0=3) if sample_id==131
recode B101cd3r (3=2) if sample_id==165
recode B101cd3r (1=0) if sample_id==167
recode B101cd3r (1=0) if sample_id==177
recode B101cd3r (4=0) if sample_id==188
recode B101cd3r (0=1) if sample_id==191
recode B101cd3r (2=3) if sample_id==214
recode B101cd3r (2=0) if sample_id==215
recode B101cd3r (2=0) if sample_id==216
recode B101cd3r (1=0) if sample_id==217
recode B101cd3r (2=0) if sample_id==219
recode B101cd3r (2=0) if sample_id==223
recode B101cd3r (2=0) if sample_id==224
recode B101cd3r (1=0) if sample_id==225
recode B101cd3r (2=0) if sample_id==231
recode B101cd3r (2=0) if sample_id==232
recode B101cd3r (2=0) if sample_id==237
recode B101cd3r (3=0) if sample_id==238
recode B101cd3r (0=2) if sample_id==242
recode B101cd3r (2=0) if sample_id==243
recode B101cd3r (0=1) if sample_id==247
recode B101cd3r (7=0) if sample_id==248
recode B101cd3r (3=2) if sample_id==250
recode B101cd3r (0=1) if sample_id==264
recode B101cd3r (0=2) if sample_id==265
recode B101cd3r (0=1) if sample_id==267
recode B101cd3r (1=2) if sample_id==270
recode B101cd3r (2=0) if sample_id==271
recode B101cd3r (1=0) if sample_id==292
recode B101cd3r (3=0) if sample_id==312
recode B101cd3r (2=0) if sample_id==314
recode B101cd3r (3=0) if sample_id==315
recode B101cd3r (0=2) if sample_id==319
recode B101cd3r (1=0) if sample_id==321
recode B101cd3r (3=0) if sample_id==339
recode B101cd3r (4=5) if sample_id==355
recode B101cd3r (2=4) if sample_id==360
recode B101cd3r (4=0) if sample_id==363
recode B101cd3r (2=0) if sample_id==364
recode B101cd3r (7=0) if sample_id==365
recode B101cd3r (1=0) if sample_id==366
recode B101cd3r (7=0) if sample_id==367
recode B101cd3r (7=0) if sample_id==368
recode B101cd3r (0=3) if sample_id==372
recode B101cd3r (5=0) if sample_id==373
recode B101cd3r (7=3) if sample_id==375
recode B101cd3r (5=4) if sample_id==376
recode B101cd3r (3=4) if sample_id==378
recode B101cd3r (3=0) if sample_id==379
recode B101cd3r (3=0) if sample_id==380
recode B101cd3r (5=0) if sample_id==381
recode B101cd3r (2=0) if sample_id==383
recode B101cd3r (2=3) if sample_id==391
recode B101cd3r (1=0) if sample_id==393
recode B101cd3r (1=3) if sample_id==394
recode B101cd3r (1=0) if sample_id==397
recode B101cd3r (3=0) if sample_id==398
recode B101cd3r (3=4) if sample_id==399
recode B101cd3r (1=2) if sample_id==400


gen beans_legumes=.
replace beans_legumes=max(B101C2r,B101D2r) if B101cd3r==B101C2r | B101cd3r==B101D2r
replace beans_legumes=max(B101C2r,B101D2r)+(min(B101C2r,B101D2r)-B101cd3r) if (B101cd3r~=B101C2r) & (B101cd3r~=B101D2r) & B101cd3r~=0  
replace beans_legumes=B101C2r+B101D2r if B101cd3r==0
recode beans_legumes (0=.) 

gen vegetables=max(B101E2,B101F2,B101G2)
gen fruits=max(B101H2,B101I2)
gen meat_egg_fish=B101J2
gen dairy=B101K2
gen oil_fats=B101L2


	foreach var in cereals_tubers beans_legumes vegetables fruits meat_egg_fish dairy oil_fats{
	svy: mean `var', over(sample_type)
	}

	gen fcs1=cereals_tubers*2
	gen fcs2=beans_legumes*3
	gen fcs3=vegetables*1
	gen fcs4=fruits*1
	gen fcs5=meat_egg_fish*4
	gen fcs6=dairy*4
	gen fcs7=oil_fats*0.5

	egen fcs=rowtotal(fcs1-fcs7) if response==1

	gen fcs_poor=0 if response==1
	replace fcs_poor=1 if fcs<21.5
	gen fcs_border=0 if response==1
	replace fcs_border=1 if (fcs>21 & fcs<35.5)
	gen fcs_accept=0  if response==1
	replace fcs_accept=1 if fcs>35

	replace fcs_poor=. if response==0
	replace fcs_border=. if response==0
	replace fcs_accept=. if response==0
	
	tab1 fcs_poor fcs_border fcs_accept
	

	
svy: mean fcs_poor, over(sample_type)
lincom [fcs_poor]Refugee - [fcs_poor]_subpop_2
svy: mean fcs_poor

svy: mean fcs_border, over(sample_type)
lincom [fcs_border]Refugee - [fcs_border]_subpop_2
svy: mean fcs_border

svy: mean fcs_accept, over(sample_type)
lincom [fcs_accept]Refugee - [fcs_accept]_subpop_2
svy: mean fcs_accept	

svy: mean fcs, over(sample_type)
lincom [fcs]Refugee - [fcs]_subpop_2
svy: mean fcs	
	
	
foreach x in A B C D E F G H I J K L{
gen B101`x'3r=B101`x'3	
}
	
foreach x in A B C D E F G H I J K L{
recode B101`x'3r (2=0)	
}
		
egen HDDS=rowtotal(B101A3r - B101L3r) if response~=0	
	
mean HDDS if HDDS~=0 // mean 3.7	
	
recode HDDS (0=3.7)	
	
svy: mean HDDS, over(sample_type)
lincom [HDDS]Refugee - [HDDS]_subpop_2
svy: mean HDDS	
	
/*MODULE-B:REDUCED COPING STRATEGY (rCSI)  
	•	The rCSI is a proxy indicator of household food insecurity that is based on a list of 
		behaviors (coping strategies). The index reflects both the frequency of each behavior (i.e. 
		how many days over the last 7 days the coping strategy was used by any member of the household) 
		and severity (i.e. how serious the strategy). The rCSI is based on a list of five food-related 
		coping strategies (Rely on less preferred/less expensive food, Borrow food or rely on friends/relatives, 
		limit portion size at mealtime, restrict adult consumption and reduce number of meals in a day) that the 
		household used in the seven days prior to the survey. 
	•	The rCSI raw scores are calculated by multiplying the frequency (number of days) with which a behavior 
		was used by the universal severity weight (Less preferred/less expensive food 1, Borrow food or rely on 
		others 2, limit portion size 1, restrict adult consumption 3 and reduce number of meals in a day 1), 
		then summing the weighted scores for each coping strategy. 
	•	The maximum raw score for the rCSI is 56, i.e. a household that used all five strategies every day 
		for the last 7 days would have a raw score of 56.
	•	Mean of rCSI score will be used for this indicator.
	•	Reference: FFP/WFP Guideline, RISING II PIRS*/


	
	foreach x in A B C D E{
	gen B102`x'r1=B102`x'1  
	replace B102`x'r1=0 if B102`x'1==2
	}

	
	gen limit=B102A2*1
	gen reduce=B102B2*1
	gen borrow=B102C2*2
	gen less=B102D2*1
	gen restrict=B102E2*3
	
	egen rcsi=rowtotal(limit reduce borrow less restrict) if response~=0
	

recode 	limit reduce borrow less restrict (.=0) if response==1
	
foreach var in limit reduce borrow less restrict{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2 
}
	
svy: mean limit reduce borrow less restrict  

svy: mean rcsi, over(sample_type)
lincom [rcsi]Refugee - [rcsi]_subpop_2
svy: mean rcsi	

foreach var in B102Ar1 B102Br1 B102Cr1 B102Dr1 B102Er1{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2 
}	
	
svy: mean B102Ar1 B102Br1 B102Cr1 B102Dr1 B102Er1	

egen food_basd_rcs_sum=rowtotal(B102Ar1 B102Br1 B102Cr1 B102Dr1 B102Er1) if response==1

gen food_basd_rcs=food_basd_rcs_sum
recode food_basd_rcs (1/5=1)

svy: mean food_basd_rcs, over(sample_type)
lincom [food_basd_rcs]Refugee - [food_basd_rcs]_subpop_2
svy: mean food_basd_rcs	

******HOUSEHOLD INCOME********

**Household MAIN income sources in the past 12 months (%)

tab1 C101_*

/*
1	A.Food crop production/sales 
2	B.Cash crop production 
3	C.Casual labor (Piece work)
4	D.Livestock production/sales 
5	E.Skilled trade/artisan 
6	F.Small business 
7	G.Charcoal selling
8	H.Firewood selling 
9	I.Other petty trade (selling doughnuts, etc.) 
10	J.Brewing local beer
11	K.Formal salary/wages
12	L.Waiving production 
13	M.Tailoring 
14	N.Others (Specify)
99	O.No productive activities that generate income
*/

forvalues i=1/15{
gen C101_`i'r=C101_`i'
}

forvalues i=1/15{
recode C101_`i'r (99=15)
}

forvalues i=1/15{
gen incm_src_12m`i'=0 if response==1
}

forvalues i=1/15{
recode incm_src_12m`i' (0=1) if C101_1r==`i' | C101_2r==`i' | C101_3r==`i' | C101_4r==`i' | C101_5r==`i' | C101_6r==`i' ///
                                | C101_7r==`i' | C101_8r==`i' | C101_9r==`i' | C101_10r==`i' | C101_11r==`i' | C101_12r==`i' ///
								 | C101_13r==`i' | C101_14r==`i' | C101_15r==`i'
}

forvalues i=1/15{
svy: mean incm_src_12m`i', over(sample_type)
lincom [incm_src_12m`i']Refugee - [incm_src_12m`i']_subpop_2
}


svy: mean incm_src_12m1 incm_src_12m2 incm_src_12m3 incm_src_12m4 incm_src_12m5 incm_src_12m6 incm_src_12m7 incm_src_12m8 incm_src_12m9 ///
          incm_src_12m10 incm_src_12m11 incm_src_12m12 incm_src_12m13 incm_src_12m14 incm_src_12m15


****Other income sources
/*
1	A.Remittance
2	B.Loans
3	C.Non-Food assistance in-kind support from UNHCR
4	D.Non-Food assistance in cash support from UNHCR
5	E.Food assistance in-kind from WFP
6	F.Food assistance in cash from WFP
7	G.Food assistance in-kind from others
8	H.Food assistance in-cash from others
9	I.Cash assistance support from others
10	J.Food assistance selling
11	K.Gift from neighbors/friends/relatives
12	L.Savings
13	M.Others (Specify)
14	N.No other sources
*/


forvalues i=1/14{
gen oth_incm_src_12m`i'=0 if response==1
}

forvalues i=1/14{
recode oth_incm_src_12m`i' (0=1) if C102_1==`i' | C102_2==`i' | C102_3==`i' | C102_4==`i' | C102_5==`i' | C102_6==`i' ///
							| C102_7==`i' | C102_8==`i' | C102_9==`i' | C102_10==`i' | C102_11==`i' | C102_12==`i' | C102_13==`i' | C102_14==`i'
}

forvalues i=1/14{
svy: mean oth_incm_src_12m1 oth_incm_src_12m2 oth_incm_src_12m3 oth_incm_src_12m4 oth_incm_src_12m5 oth_incm_src_12m6 oth_incm_src_12m7 ///
			oth_incm_src_12m8 oth_incm_src_12m9 oth_incm_src_12m10 oth_incm_src_12m11 oth_incm_src_12m12 oth_incm_src_12m13 ///
			oth_incm_src_12m14, over(sample_type)

}


forvalues i=1/14{
svy: mean oth_incm_src_12m1 oth_incm_src_12m2 oth_incm_src_12m3 oth_incm_src_12m4 oth_incm_src_12m5 oth_incm_src_12m6 oth_incm_src_12m7 ///
			oth_incm_src_12m8 oth_incm_src_12m9 oth_incm_src_12m10 oth_incm_src_12m11 oth_incm_src_12m12 oth_incm_src_12m13 ///
			oth_incm_src_12m14

}



forvalues i=1/14{
svy: mean oth_incm_src_12m`i', over(sample_type)
lincom [oth_incm_src_12m`i']Refugee - [oth_incm_src_12m`i']_subpop_2
}


*Percentage of households reported their main income activities remained SAME compared to those before March 2020/ COVID-19 pandemic?

gen C103r=0 if response==1
recode C103r (0=1) if C103==1

svy: mean C103r, over(sample_type)
lincom [C103r]Refugee - [C103r]_subpop_2

**Percentage of households reported their main income activities remained SAME compared to those before March 2020/ COVID-19 pandemic?

forvalues i=1/15{
gen C104_`i'r=C104_`i'
}

forvalues i=1/15{
recode C104_`i'r (99=15)
}

forvalues i=1/15{
gen incm_src_cvd19_`i'=0 if C103~=1
}



forvalues i=1/15{
recode incm_src_cvd19_`i' (0=1) if C104_1r==`i' | C104_2r==`i' | C104_3r==`i' | C104_4r==`i' | C104_5r==`i' | C104_6r==`i' ///
                                | C104_7r==`i' | C104_8r==`i' | C104_9r==`i' | C104_10r==`i' | C104_11r==`i' | C104_12r==`i' ///
								 | C104_13r==`i' | C104_14r==`i' | C104_15r==`i'
}

forvalues i=1/15{
recode incm_src_cvd19_`i' (0=.) if response==0
}

forvalues i=1/15{
svy: mean incm_src_cvd19_`i', over(sample_type)
lincom [incm_src_cvd19_`i']Refugee - [incm_src_cvd19_`i']_subpop_2
}

forvalues i=1/15{
svy: mean incm_src_12m`i' if C103r==0, over(sample_type)
lincom [incm_src_12m`i']Refugee - [incm_src_12m`i']_subpop_2
}



svy: mean incm_src_cvd19_1 incm_src_cvd19_2 incm_src_cvd19_3 incm_src_cvd19_4 incm_src_cvd19_5 incm_src_cvd19_6 ///
			incm_src_cvd19_7 incm_src_cvd19_8 incm_src_cvd19_9 incm_src_cvd19_10 incm_src_cvd19_11 ///
			incm_src_cvd19_12 incm_src_cvd19_13 incm_src_cvd19_14 incm_src_cvd19_15

svy: mean incm_src_12m1 incm_src_12m2 incm_src_12m3 incm_src_12m4 incm_src_12m5 incm_src_12m6 incm_src_12m7 incm_src_12m8 incm_src_12m9 ///
          incm_src_12m10 incm_src_12m11 incm_src_12m12 incm_src_12m13 incm_src_12m14 incm_src_12m15 if C103r==0


*****Syntax from 2. Misizi_PE_Indicator_Analysis.do file

**Average monthly income in the past 12 months

svy: mean incm_past12_rwf, over(sample_type)
lincom [incm_past12_rwf]Refugee - [incm_past12_rwf]_subpop_2

svy: mean incm_past12_rwf

forvalues i=1/5{
gen incm_cat_12m`i'=0 if response==1
}

recode incm_cat_12m1 (0=1) if incm_past12_rwf>=0 & incm_past12_rwf<25000
recode incm_cat_12m2 (0=1) if incm_past12_rwf>=25000 & incm_past12_rwf<50000
recode incm_cat_12m3 (0=1) if incm_past12_rwf>=50000 & incm_past12_rwf<75000
recode incm_cat_12m4 (0=1) if incm_past12_rwf>=75000 & incm_past12_rwf<100000
recode incm_cat_12m5 (0=1) if incm_past12_rwf>=100000

svy: mean incm_cat_12m1 incm_cat_12m2 incm_cat_12m3 incm_cat_12m4 incm_cat_12m5

tab1 incm_cat_12m1 incm_cat_12m2 incm_cat_12m3 incm_cat_12m4 incm_cat_12m5


**Average monthly income before COVID-19

svy: mean incm_bCVD19_rwf, over(sample_type)
lincom [incm_bCVD19_rwf]Refugee - [incm_bCVD19_rwf]_subpop_2

svy: mean incm_bCVD19_rwf

forvalues i=1/5{
gen incm_cat_cvd`i'=0 if response==1
}

recode incm_cat_cvd1 (0=1) if incm_bCVD19_rwf>=0 & incm_bCVD19_rwf<25000
recode incm_cat_cvd2 (0=1) if incm_bCVD19_rwf>=25000 & incm_bCVD19_rwf<50000
recode incm_cat_cvd3 (0=1) if incm_bCVD19_rwf>=50000 & incm_bCVD19_rwf<75000
recode incm_cat_cvd4 (0=1) if incm_bCVD19_rwf>=75000 & incm_bCVD19_rwf<100000
recode incm_cat_cvd5 (0=1) if incm_bCVD19_rwf>=100000

svy: mean incm_cat_cvd1 incm_cat_cvd2 incm_cat_cvd3 incm_cat_cvd4 incm_cat_cvd5

tab1 incm_cat_cvd1 incm_cat_cvd2 incm_cat_cvd3 incm_cat_cvd4 incm_cat_cvd5

**Reasons of your household income decreased/stayed same over the past three years

/*
1	A.Bad harvest 
2	B.Skipped some seasons for planting 
3	C.High cost for agriculture/livestock inputs and services
4	D.Agricultural/farm plots were wetland
5	E.Lack of financial capacity agricultural inputs/services
6	F.Delayed planting 
7	G.Less production due to the inappropriate seed verities for this region
8	H.Crop pests or diseases attack (e.g., Fall Army worm)
9	I.Small frame land for cultivation
10	J.Crop land flooded during planting/harvesting time 
11	K.Crop damaged/less production due to bad weather condition
12	L.Low price of the agriculture/livestock produces 
13	M.Less accessibility to the market
14	N.Job loss/lack of wage labor or job opportunity
15	O.Less mobility/accessibility due to COVID-19
16	P.Could not go out for work due to long duration of heavy rain/drought
17	Q.Others (Specify) 
99	R.Don’t know/No reason 
*/


forvalues i=1/18{
gen C110r_`i'=C110_`i'
}

forvalues i=1/18{
recode C110r_`i' (99=18)
}


forvalues i=1/18{
gen reasn_incm_decr`i'=0 if C107==2 | C107==3
recode reasn_incm_decr`i' (0=1) if C110r_1==`i' | C110r_2==`i' | C110r_3==`i' | C110r_4==`i' | C110r_5==`i' | C110r_6==`i' ///
									 | C110r_7==`i' | C110r_8==`i' | C110r_9==`i' | C110r_10==`i' | C110r_11==`i' | C110r_12==`i' ///
									  | C110r_13==`i' | C110r_14==`i' | C110r_15==`i' | C110r_16==`i' | C110r_17==`i' | C110r_18==`i'
}

forvalues i=1/18{
svy: mean reasn_incm_decr`i', over(sample_type)
lincom [reasn_incm_decr`i']Refugee - [reasn_incm_decr`i']_subpop_2
}


tabulate reasn_incm_decr1 sample_type


tab C110_others


svy: mean reasn_incm_decr1 reasn_incm_decr2 reasn_incm_decr3 reasn_incm_decr4 reasn_incm_decr5 reasn_incm_decr6 reasn_incm_decr7 ///
			reasn_incm_decr8 reasn_incm_decr9 reasn_incm_decr10 reasn_incm_decr11 reasn_incm_decr12 reasn_incm_decr13 reasn_incm_decr14 ///
			reasn_incm_decr15 reasn_incm_decr16 reasn_incm_decr17 reasn_incm_decr18 

**Suggestions to address challenges/factors that might negatively effect on household income

/*
1	A.Strengthen grant to support agricultural and livestock activities  
2	B.Need training on improved agricultural and livestock practices
3	C.Strengthen quality and improved seed supply system
4	D.Access to the agriculture and livestock extension services
5	E.Increase plot size allocation
6	F.Need proper idea on land preparation and crop seasonal calendar for timely plantation
7	G.Timely fertilizer supply
8	H.Ensure proper drainage system to get rid from water lagging
9	I.Proper management of natural water resources
10	J.Continue project support after graduation
11	K.Supply kits/medication to fight against COVID-19
12	L.Others (Specify) 
99	M.Don’t know/Not any 
*/

tab1 C111_*

forvalues i=1/13{
gen C111r_`i'=C111_`i'
recode C111r_`i' (99=13)
}

forvalues i=1/13{
gen incm_sugg_`i'=0 if response==1
recode incm_sugg_`i' (0=1) if C111r_1==`i' | C111r_2==`i' | C111r_3==`i' | C111r_4==`i' | C111r_5==`i' | C111r_6==`i' ///
						 | C111r_7==`i' | C111r_8==`i' | C111r_9==`i' | C111r_10==`i' | C111r_12==`i' | C111r_13==`i'
}

forvalues i=1/13{
svy: mean incm_sugg_`i', over(sample_type)
lincom [incm_sugg_`i']Refugee - [incm_sugg_`i']_subpop_2
}

svy: mean incm_sugg_1 incm_sugg_2 incm_sugg_3 incm_sugg_4 incm_sugg_5 incm_sugg_6 incm_sugg_7 incm_sugg_8 /// 
                 incm_sugg_9 incm_sugg_10 incm_sugg_11 incm_sugg_12 incm_sugg_13 


tab C111_others

**MODULE-D: CROP PRODUCTION AND VALUE CHAIN PRACTICES

**% of households have access to any land for crop production

gen D101r=D101
recode D101r (2=0)

svy: mean D101r, over(sample_type)
lincom [D101r]Refugee - [D101r]_subpop_2

svy: mean D101r

tabulate D101 sample_type


**Land size that the HH have access


svy: mean D102A, over(sample_type)
lincom [D102A]Refugee - [D102A]_subpop_2

svy: mean D102A


svy: mean D102B, over(sample_type)
lincom [D102B]Refugee - [D102B]_subpop_2

svy: mean D102B

egen accss_land_tot_are=rowtotal(D102A D102B) if D101==1

svy: mean accss_land_tot_are, over(sample_type)
lincom [accss_land_tot_are]Refugee - [accss_land_tot_are]_subpop_2

svy: mean accss_land_tot_are


gen accss_landA_hect=D102A/100
gen accss_landB_hect=D102B/100
gen accss_land_tot_hect=accss_land_tot_are/100

svy: mean accss_landA_hect, over(sample_type)
lincom [accss_landA_hect]Refugee - [accss_landA_hect]_subpop_2

svy: mean accss_landA_hect


svy: mean accss_landB_hect, over(sample_type)
lincom [accss_landB_hect]Refugee - [accss_landB_hect]_subpop_2

svy: mean accss_landB_hect


svy: mean accss_land_tot_hect, over(sample_type)
lincom [accss_land_tot_hect]Refugee - [accss_land_tot_hect]_subpop_2

svy: mean accss_land_tot_hect

***Sources of land

tab1 D103_* // obeservation available up to variable D103_4

/*
1	A.Own household land
2	B.Government allocation
3	C.Jointly by UNHCR/Misizi and local authority
4	D.Other NGOs/projects
5	E.Borrowed
6	F.Leased 
7	G.Given by a friend/relative 
8	H.Given by host-community 
9	I.Others (specify)
99	J.Don’t know
88	K.Refused
*/

**From 2. Misizi_PE_Indicator_Analysis.do file

tab1 land_support*


forvalues i=1/11{
svy: mean land_support`i', over(sample_type)
lincom [land_support`i']Refugee - [land_support`i']_subpop_2
}


svy: mean land_support1 land_support2 land_support3 land_support4 land_support5 land_support6 land_support7 land_support8 land_support9 


**% of households who have access to land currently growing crops/vegetables

gen D104r=D104
recode D104r (2=0)

svy: mean D104r, over(sample_type)
lincom [D104r]Refugee - [D104r]_subpop_2

svy: mean D104r

**SEASON-A (September 2020 - February 2021)

**From 2. Misizi_PE_Indicator_Analysis.do file

svy: mean maize_SnA bean_SnA sbean_SnA, over(sample_type)
lincom [maize_SnA]Refugee - [maize_SnA]_subpop_2
lincom [bean_SnA]Refugee - [bean_SnA]_subpop_2
lincom [sbean_SnA]Refugee - [sbean_SnA]_subpop_2

svy: mean maize_SnA bean_SnA sbean_SnA

tabulate maize_SnA sample_type

foreach var in D105A2A D105A2B D105A2C{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in D105A2A D105A2B D105A2C{
svy: mean `var'
}

foreach var in maize_land_hct_SnA bean_land_hct_SnA sbean_land_hct_SnA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_land_hct_SnA bean_land_hct_SnA sbean_land_hct_SnA{
svy: mean `var'
}


foreach var in prod_maiz_snA prod_bean_snA prod_sbean_snA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in prod_maiz_snA prod_bean_snA prod_sbean_snA{
svy: mean `var'
}

foreach var in maize_yld_SnA bean_yld_SnA sbean_yld_SnA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_yld_SnA bean_yld_SnA sbean_yld_SnA{
svy: mean `var'
}

gen sold_maiz_snA=(D105A5A_1 *50)+(D105A5A_2 *1.5)+D105A5A_3
gen con_maiz_snA=(D105A6A_1 *50)+(D105A6A_2 *1.5)+D105A6A_3
gen stock_maiz_snA=(D105A7A_1 *50)+(D105A7A_2 *1.5)+D105A7A_3
gen give_maiz_snA=(D105A8A_1 *50)+(D105A8A_2 *1.5)+D105A8A_3

gen sold_maiz_pr_snA=(sold_maiz_snA/prod_maiz_snA)*100
gen con_maiz_pr_snA=(con_maiz_snA/prod_maiz_snA)*100
gen stock_maiz_pr_snA=(stock_maiz_snA/prod_maiz_snA)*100
gen give_maiz_pr_snA=(give_maiz_snA/prod_maiz_snA)*100

foreach var in sold_maiz_pr_snA con_maiz_pr_snA stock_maiz_pr_snA give_maiz_pr_snA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_maiz_pr_snA con_maiz_pr_snA stock_maiz_pr_snA give_maiz_pr_snA{
svy: mean `var'
}


gen sold_bean_snA=(D105A5B_1 *50)+(D105A5B_2 *1.5)+D105A5B_3
gen con_bean_snA=(D105A6B_1 *50)+(D105A6B_2 *1.5)+D105A6B_3
gen stock_bean_snA=(D105A7B_1 *50)+(D105A7B_2 *1.5)+D105A7B_3
gen give_bean_snA=(D105A8B_1 *50)+(D105A8B_2 *1.5)+D105A8B_3

gen sold_bean_pr_snA=(sold_bean_snA/prod_bean_snA)*100
gen con_bean_pr_snA=(con_bean_snA/prod_bean_snA)*100
gen stock_bean_pr_snA=(stock_bean_snA/prod_bean_snA)*100
gen give_bean_pr_snA=(give_bean_snA/prod_bean_snA)*100

foreach var in sold_bean_pr_snA con_bean_pr_snA stock_bean_pr_snA give_bean_pr_snA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_bean_pr_snA con_bean_pr_snA stock_bean_pr_snA give_bean_pr_snA{
svy: mean `var'
}

gen sold_sbean_snA=(D105A5C_1 *50)+(D105A5C_2 *1.5)+D105A5C_3
gen con_sbean_snA=(D105A6C_1 *50)+(D105A6C_2 *1.5)+D105A6C_3
gen stock_sbean_snA=(D105A7C_1 *50)+(D105A7C_2 *1.5)+D105A7C_3
gen give_sbean_snA=(D105A8C_1 *50)+(D105A8C_2 *1.5)+D105A8C_3

gen sold_sbean_pr_snA=(sold_sbean_snA/prod_sbean_snA)*100
gen con_sbean_pr_snA=(con_sbean_snA/prod_sbean_snA)*100
gen stock_sbean_pr_snA=(stock_sbean_snA/prod_sbean_snA)*100
gen give_sbean_pr_snA=(give_sbean_snA/prod_sbean_snA)*100

foreach var in sold_sbean_pr_snA con_sbean_pr_snA stock_sbean_pr_snA give_sbean_pr_snA{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_sbean_pr_snA con_sbean_pr_snA stock_sbean_pr_snA give_sbean_pr_snA{
svy: mean `var'
}



**SEASON-B (March – June 2021)

**From 2. Misizi_PE_Indicator_Analysis.do file

svy: mean maize_SnB bean_SnB sbean_SnB, over(sample_type)
lincom [maize_SnB]Refugee - [maize_SnB]_subpop_2
lincom [bean_SnB]Refugee - [bean_SnB]_subpop_2
lincom [sbean_SnB]Refugee - [sbean_SnB]_subpop_2

svy: mean maize_SnB bean_SnB sbean_SnB

tabulate maize_SnB sample_type


foreach var in D105B2A D105B2B D105B2C{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in D105B2A D105B2B D105B2C{
svy: mean `var'
}


foreach var in maize_land_hct_SnB bean_land_hct_SnB sbean_land_hct_SnB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_land_hct_SnB bean_land_hct_SnB sbean_land_hct_SnB{
svy: mean `var'
}


foreach var in prod_maiz_snB prod_bean_snB prod_sbean_snB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in prod_maiz_snB prod_bean_snB prod_sbean_snB{
svy: mean `var'
}

foreach var in maize_yld_SnB bean_yld_SnB sbean_yld_SnB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_yld_SnB bean_yld_SnB sbean_yld_SnB{
svy: mean `var'
}

gen sold_maiz_snB=(D105B5A_1 *50)+(D105B5A_2 *1.5)+D105B5A_3
gen con_maiz_snB=(D105B6A_1 *50)+(D105B6A_2 *1.5)+D105B6A_3
gen stock_maiz_snB=(D105B7A_1 *50)+(D105B7A_2 *1.5)+D105B7A_3
gen give_maiz_snB=(D105B8A_1 *50)+(D105B8A_2 *1.5)+D105B8A_3

gen sold_maiz_pr_snB=(sold_maiz_snB/prod_maiz_snB)*100
gen con_maiz_pr_snB=(con_maiz_snB/prod_maiz_snB)*100
gen stock_maiz_pr_snB=(stock_maiz_snB/prod_maiz_snB)*100
gen give_maiz_pr_snB=(give_maiz_snB/prod_maiz_snB)*100

foreach var in sold_maiz_pr_snB con_maiz_pr_snB stock_maiz_pr_snB give_maiz_pr_snB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_maiz_pr_snB con_maiz_pr_snB stock_maiz_pr_snB give_maiz_pr_snB{
svy: mean `var'
}


gen sold_bean_snB=(D105B5B_1 *50)+(D105B5B_2 *1.5)+D105B5B_3
gen con_bean_snB=(D105B6B_1 *50)+(D105B6B_2 *1.5)+D105B6B_3
gen stock_bean_snB=(D105B7B_1 *50)+(D105B7B_2 *1.5)+D105B7B_3
gen give_bean_snB=(D105B8B_1 *50)+(D105B8B_2 *1.5)+D105B8B_3

gen sold_bean_pr_snB=(sold_bean_snB/prod_bean_snB)*100
gen con_bean_pr_snB=(con_bean_snB/prod_bean_snB)*100
gen stock_bean_pr_snB=(stock_bean_snB/prod_bean_snB)*100
gen give_bean_pr_snB=(give_bean_snB/prod_bean_snB)*100

foreach var in sold_bean_pr_snB con_bean_pr_snB stock_bean_pr_snB give_bean_pr_snB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_bean_pr_snB con_bean_pr_snB stock_bean_pr_snB give_bean_pr_snB{
svy: mean `var'
}

gen sold_sbean_snB=(D105B5C_1 *50)+(D105B5C_2 *1.5)+D105B5C_3
gen con_sbean_snB=(D105B6C_1 *50)+(D105B6C_2 *1.5)+D105B6C_3
gen stock_sbean_snB=(D105B7C_1 *50)+(D105B7C_2 *1.5)+D105B7C_3
gen give_sbean_snB=(D105B8C_1 *50)+(D105B8C_2 *1.5)+D105B8C_3

gen sold_sbean_pr_snB=(sold_sbean_snB/prod_sbean_snB)*100
gen con_sbean_pr_snB=(con_sbean_snB/prod_sbean_snB)*100
gen stock_sbean_pr_snB=(stock_sbean_snB/prod_sbean_snB)*100
gen give_sbean_pr_snB=(give_sbean_snB/prod_sbean_snB)*100

foreach var in sold_sbean_pr_snB con_sbean_pr_snB stock_sbean_pr_snB give_sbean_pr_snB{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_sbean_pr_snB con_sbean_pr_snB stock_sbean_pr_snB give_sbean_pr_snB{
svy: mean `var'
}



**SEASON-A (September 2021 - February 2022)

**From 2. Misizi_PE_Indicator_Analysis.do file

svy: mean maize_SnAa bean_SnAa sbean_SnAa, over(sample_type)
lincom [maize_SnAa]Refugee - [maize_SnAa]_subpop_2
lincom [bean_SnAa]Refugee - [bean_SnAa]_subpop_2
lincom [sbean_SnAa]Refugee - [sbean_SnAa]_subpop_2

svy: mean maize_SnAa bean_SnAa sbean_SnAa

tabulate maize_SnAa sample_type

foreach var in D105Aa2A D105Aa2B D105Aa2C{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in D105Aa2A D105Aa2B D105Aa2C{
svy: mean `var'
}

foreach var in maize_land_hct_SnAa bean_land_hct_SnAa sbean_land_hct_SnAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_land_hct_SnAa bean_land_hct_SnAa sbean_land_hct_SnAa{
svy: mean `var'
}


foreach var in prod_maiz_snAa prod_bean_snAa prod_sbean_snAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in prod_maiz_snAa prod_bean_snAa prod_sbean_snAa{
svy: mean `var'
}

foreach var in maize_yld_SnAa bean_yld_SnAa sbean_yld_SnAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in maize_yld_SnAa bean_yld_SnAa sbean_yld_SnAa{
svy: mean `var'
}


gen sold_maiz_snAa=(D105Aa5A_1 *50)+(D105Aa5A_2 *1.5)+D105Aa5A_3
gen con_maiz_snAa=(D105Aa6A_1 *50)+(D105Aa6A_2 *1.5)+D105Aa6A_3
gen stock_maiz_snAa=(D105Aa7A_1 *50)+(D105Aa7A_2 *1.5)+D105Aa7A_3
gen give_maiz_snAa=(D105Aa8A_1 *50)+(D105Aa8A_2 *1.5)+D105Aa8A_3

gen sold_maiz_pr_snAa=(sold_maiz_snAa/prod_maiz_snAa)*100
gen con_maiz_pr_snAa=(con_maiz_snAa/prod_maiz_snAa)*100
gen stock_maiz_pr_snAa=(stock_maiz_snAa/prod_maiz_snAa)*100
gen give_maiz_pr_snAa=(give_maiz_snAa/prod_maiz_snAa)*100

foreach var in sold_maiz_pr_snAa con_maiz_pr_snAa stock_maiz_pr_snAa give_maiz_pr_snAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_maiz_pr_snAa con_maiz_pr_snAa stock_maiz_pr_snAa give_maiz_pr_snAa{
svy: mean `var'
}


gen sold_bean_snAa=(D105Aa5B_1 *50)+(D105Aa5B_2 *1.5)+D105Aa5B_3
gen con_bean_snAa=(D105Aa6B_1 *50)+(D105Aa6B_2 *1.5)+D105Aa6B_3
gen stock_bean_snAa=(D105Aa7B_1 *50)+(D105Aa7B_2 *1.5)+D105Aa7B_3
gen give_bean_snAa=(D105Aa8B_1 *50)+(D105Aa8B_2 *1.5)+D105Aa8B_3

gen sold_bean_pr_snAa=(sold_bean_snAa/prod_bean_snAa)*100
gen con_bean_pr_snAa=(con_bean_snAa/prod_bean_snAa)*100
gen stock_bean_pr_snAa=(stock_bean_snAa/prod_bean_snAa)*100
gen give_bean_pr_snAa=(give_bean_snAa/prod_bean_snAa)*100

foreach var in sold_bean_pr_snAa con_bean_pr_snAa stock_bean_pr_snAa give_bean_pr_snAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_bean_pr_snAa con_bean_pr_snAa stock_bean_pr_snAa give_bean_pr_snAa{
svy: mean `var'
}

gen sold_sbean_snAa=(D105Aa5C_1 *50)+(D105Aa5C_2 *1.5)+D105Aa5C_3
gen con_sbean_snAa=(D105Aa6C_1 *50)+(D105Aa6C_2 *1.5)+D105Aa6C_3
gen stock_sbean_snAa=(D105Aa7C_1 *50)+(D105Aa7C_2 *1.5)+D105Aa7C_3
gen give_sbean_snAa=(D105Aa8C_1 *50)+(D105Aa8C_2 *1.5)+D105Aa8C_3

gen sold_sbean_pr_snAa=(sold_sbean_snAa/prod_sbean_snAa)*100
gen con_sbean_pr_snAa=(con_sbean_snAa/prod_sbean_snAa)*100
gen stock_sbean_pr_snAa=(stock_sbean_snAa/prod_sbean_snAa)*100
gen give_sbean_pr_snAa=(give_sbean_snAa/prod_sbean_snAa)*100

foreach var in sold_sbean_pr_snAa con_sbean_pr_snAa stock_sbean_pr_snAa give_sbean_pr_snAa{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in sold_sbean_pr_snAa con_sbean_pr_snAa stock_sbean_pr_snAa give_sbean_pr_snAa{
svy: mean `var'
}


************************************************************************************
*REINVESTMENT

*From 2. Misizi_PE_Indicator_Analysis.do file

tab1 use_incm_sell_agri*

use_incm_sell_agri`i'


foreach var in use_incm_sell_agri1 use_incm_sell_agri2 use_incm_sell_agri3 use_incm_sell_agri4 use_incm_sell_agri5 use_incm_sell_agri6 use_incm_sell_agri7 use_incm_sell_agri8{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in use_incm_sell_agri1 use_incm_sell_agri2 use_incm_sell_agri3 use_incm_sell_agri4 use_incm_sell_agri5 use_incm_sell_agri6 use_incm_sell_agri7 use_incm_sell_agri8{
svy: mean `var'
}

**What types of agriculture sub-sector supports have you received from Misizi Marshland project?


/*
1	A.Farming (rain-fed farming, irrigated farming etc.)
2	B.Livestock (animals, poultry etc.)
3	C.Fishery
4	D.Others (Specify)
9	E.None 
*/


forvalues i=1/5{
gen D108r_`i'=D108_`i'
recode D108r_`i' (9=5)
}

forvalues i=1/5{
gen agri_subs_supp_`i'=0 if curr_prod_misizi==1
recode agri_subs_supp_`i' (0=1) if D108r_1==`i' | D108r_2==`i' | D108r_3==`i' | D108r_4==`i'
}

tab1 agri_subs_supp_*

foreach var in agri_subs_supp_1 agri_subs_supp_2 agri_subs_supp_3 agri_subs_supp_4 agri_subs_supp_5{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in agri_subs_supp_1 agri_subs_supp_2 agri_subs_supp_3 agri_subs_supp_4 agri_subs_supp_5{
svy: mean `var'
}

tabulate curr_prod_misizi sample_type

**% of households received crop production supports, trainings or inputs

foreach x in A B C D E F G H I J{
gen D109ar_`x'=D109a_`x'
recode D109ar_`x' (2=0)
}


foreach var in D109ar_A D109ar_B D109ar_C D109ar_D D109ar_E D109ar_F D109ar_G D109ar_H D109ar_I D109ar_J{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

foreach var in D109ar_A D109ar_B D109ar_C D109ar_D D109ar_E D109ar_F D109ar_G D109ar_H D109ar_I D109ar_J{
svy: mean `var'
}


tabulate D104 sample_type


/*
1	A.Misizi Marshland project/UNHCR
2	B.FAO
3	C.WFP
4	D.Other UN agencies 
5	E.Local NGOs 
6	F.INGOs 
7	G.Cooperatives/farmer groups/ associations 
8	H.Others (specify)
99	I.Don’t know
*/

forvalues i=1/9{
foreach x in A B C D E F G H I J{
gen D109br_`x'`i'=D109b_`x'`i'
recode D109br_`x'`i' (99=9)
}
}

forvalues i=1/9{
gen D109_A`i'=0 if D109ar_A==1 
recode D109_A`i' (0=1) if D109br_A1==`i' | D109br_A2==`i' | D109br_A3==`i' | D109br_A4==`i' | /// 
                          D109br_A5==`i' | D109br_A6==`i' | D109br_A7==`i' | D109br_A8==`i' | D109br_A9==`i'
}


forvalues i=1/9{
svy: mean D109_A`i', over(sample_type)
}

forvalues i=1/9{
svy: mean D109_A`i'
}


forvalues i=1/9{
gen D109_B`i'=0 if D109ar_B==1 
recode D109_B`i' (0=1) if D109br_B1==`i' | D109br_B2==`i' | D109br_B3==`i' | D109br_B4==`i' | /// 
                          D109br_B5==`i' | D109br_B6==`i' | D109br_B7==`i' | D109br_B8==`i' | D109br_B9==`i'
}



svy: mean D109_B1 D109_B2 D109_B3 D109_B4 D109_B5 D109_B6 D109_B7 D109_B8 D109_B9, over(sample_type)
svy: mean D109_B1 D109_B2 D109_B3 D109_B4 D109_B5 D109_B6 D109_B7 D109_B8 D109_B9



forvalues i=1/9{
gen D109_C`i'=0 if D109ar_C==1 
recode D109_C`i' (0=1) if D109br_C1==`i' | D109br_C2==`i' | D109br_C3==`i' | D109br_C4==`i' | /// 
                          D109br_C5==`i' | D109br_C6==`i' | D109br_C7==`i' | D109br_C8==`i' | D109br_C9==`i'
}



svy: mean D109_C1 D109_C2 D109_C3 D109_C4 D109_C5 D109_C6 D109_C7 D109_C8 D109_C9, over(sample_type)
svy: mean D109_C1 D109_C2 D109_C3 D109_C4 D109_C5 D109_C6 D109_C7 D109_C8 D109_C9


forvalues i=1/9{
gen D109_D`i'=0 if D109ar_D==1 
recode D109_D`i' (0=1) if D109br_D1==`i' | D109br_D2==`i' | D109br_D3==`i' | D109br_D4==`i' | /// 
                          D109br_D5==`i' | D109br_D6==`i' | D109br_D7==`i' | D109br_D8==`i' | D109br_D9==`i'
}



svy: mean D109_D1 D109_D2 D109_D3 D109_D4 D109_D5 D109_D6 D109_D7 D109_D8 D109_D9, over(sample_type)
svy: mean D109_D1 D109_D2 D109_D3 D109_D4 D109_D5 D109_D6 D109_D7 D109_D8 D109_D9


forvalues i=1/9{
gen D109_E`i'=0 if D109ar_E==1 
recode D109_E`i' (0=1) if D109br_E1==`i' | D109br_E2==`i' | D109br_E3==`i' | D109br_E4==`i' | /// 
                          D109br_E5==`i' | D109br_E6==`i' | D109br_E7==`i' | D109br_E8==`i' | D109br_E9==`i'
}



svy: mean D109_E1 D109_E2 D109_E3 D109_E4 D109_E5 D109_E6 D109_E7 D109_E8 D109_E9, over(sample_type)
svy: mean D109_E1 D109_E2 D109_E3 D109_E4 D109_E5 D109_E6 D109_E7 D109_E8 D109_E9


forvalues i=1/9{
gen D109_F`i'=0 if D109ar_F==1 
recode D109_F`i' (0=1) if D109br_F1==`i' | D109br_F2==`i' | D109br_F3==`i' | D109br_F4==`i' | /// 
                          D109br_F5==`i' | D109br_F6==`i' | D109br_F7==`i' | D109br_F8==`i' | D109br_F9==`i'
}


svy: mean D109_F1 D109_F2 D109_F3 D109_F4 D109_F5 D109_F6 D109_F7 D109_F8 D109_F9, over(sample_type)
svy: mean D109_F1 D109_F2 D109_F3 D109_F4 D109_F5 D109_F6 D109_F7 D109_F8 D109_F9


forvalues i=1/9{
gen D109_G`i'=0 if D109ar_G==1 
recode D109_G`i' (0=1) if D109br_G1==`i' | D109br_G2==`i' | D109br_G3==`i' | D109br_G4==`i' | /// 
                          D109br_G5==`i' | D109br_G6==`i' | D109br_G7==`i' | D109br_G8==`i' | D109br_G9==`i'
}


svy: mean D109_G1 D109_G2 D109_G3 D109_G4 D109_G5 D109_G6 D109_G7 D109_G8 D109_G9, over(sample_type)
svy: mean D109_G1 D109_G2 D109_G3 D109_G4 D109_G5 D109_G6 D109_G7 D109_G8 D109_G9


forvalues i=1/9{
gen D109_H`i'=0 if D109ar_H==1 
recode D109_H`i' (0=1) if D109br_H1==`i' | D109br_H2==`i' | D109br_H3==`i' | D109br_H4==`i' | /// 
                          D109br_H5==`i' | D109br_H6==`i' | D109br_H7==`i' | D109br_H8==`i' | D109br_H9==`i'
}


svy: mean D109_H1 D109_H2 D109_H3 D109_H4 D109_H5 D109_H6 D109_H7 D109_H8 D109_H9, over(sample_type)
svy: mean D109_H1 D109_H2 D109_H3 D109_H4 D109_H5 D109_H6 D109_H7 D109_H8 D109_H9

forvalues i=1/9{
gen D109_I`i'=0 if D109ar_I==1 
recode D109_I`i' (0=1) if D109br_I1==`i' | D109br_I2==`i' | D109br_I3==`i' | D109br_I4==`i' | /// 
                          D109br_I5==`i' | D109br_I6==`i' | D109br_I7==`i' | D109br_I8==`i' | D109br_I9==`i'
}


svy: mean D109_I1 D109_I2 D109_I3 D109_I4 D109_I5 D109_I6 D109_I7 D109_I8 D109_I9, over(sample_type)
svy: mean D109_I1 D109_I2 D109_I3 D109_I4 D109_I5 D109_I6 D109_I7 D109_I8 D109_I9


forvalues i=1/9{
gen D109_J`i'=0 if D109ar_J==1 
recode D109_J`i' (0=1) if D109br_J1==`i' | D109br_J2==`i' | D109br_J3==`i' | D109br_J4==`i' | /// 
                          D109br_J5==`i' | D109br_J6==`i' | D109br_J7==`i' | D109br_J8==`i' | D109br_J9==`i'
}


svy: mean D109_J1 D109_J2 D109_J3 D109_J4 D109_J5 D109_J6 D109_J7 D109_J8 D109_J9, over(sample_type)
svy: mean D109_J1 D109_J2 D109_J3 D109_J4 D109_J5 D109_J6 D109_J7 D109_J8 D109_J9


****IMPROVED AGRICULTURAL PRACTICES

/*
1	A.Quality seeds (truthful labeling/certified) [Package seeds with germination rate 80% or more, collected from a trusted sources e.g. Government, Misizi project, agro-dealers, agriculture cooperatives]  
2	B.Improved varieties (hybrid, flood/drought resistant, shorter-term harvesting etc.) [Involves using varieties bred by local or international research institutions, mostly for the following characteristics – yield, drought tolerance, disease resistance, ease of preservation, taste, etc.]
3	C.Organic/bio pesticides (use of liquid manure, pheromone trap, neem oil, ash, plant extract etc.)
4	D.Compost/organic fertilizers (livestock manure, plant residues/leaves, earthworm casting/vermi-compost etc.) 
5	E.Micro-irrigation (drip, surface, sprinkler etc.) 
9	F.None
*/

tab1 D110_*

forvalues i=1/6{
gen D110r_`i'=D110_`i'
recode D110r_`i' (9=6)
}

forvalues i=1/6{
gen agri_prac`i'=0 if D104==1
recode agri_prac`i' (0=1) if D110r_1==`i' | D110r_2==`i' | D110r_3==`i' | D110r_4==`i' | D110r_5==`i' | D110r_6==`i'
}


egen agri_prac_sum=rowtotal(agri_prac1-agri_prac6) if D104==1

recode agri_prac_sum (1/5=0) if agri_prac6==1

gen agri_prac_atl1=agri_prac_sum
recode agri_prac_atl1 (0=0) (1/6=1)

gen agri_prac_atl3=agri_prac_sum
recode agri_prac_atl3 (0/2=0) (3/6=1)



tab agri_prac_sum

svy: mean agri_prac1 agri_prac2 agri_prac3 agri_prac4 agri_prac5 agri_prac6, over(sample_type)
svy: mean agri_prac1 agri_prac2 agri_prac3 agri_prac4 agri_prac5 agri_prac6


foreach var in agri_prac1 agri_prac2 agri_prac3 agri_prac4 agri_prac5 agri_prac6{
svy: mean `var', over(sample_type)
lincom [`var']Refugee - [`var']_subpop_2
}

svy: mean agri_prac_atl1, over(sample_type)
lincom [agri_prac_atl1]Refugee - [agri_prac_atl1]_subpop_2

svy: mean agri_prac_atl1


svy: mean agri_prac_atl3, over(sample_type)
lincom [agri_prac_atl3]Refugee - [agri_prac_atl3]_subpop_2

svy: mean agri_prac_atl3

*% of households with improved value chain practices during last 12 months

/*
1	A.Purchase inputs through agro-dealers and/or agriculture cooperatives
2	B.Selling or marketing produce through agro-vets/ community associations/cooperatives
3	C.Selling or marketing produce through collection centers/local markets
4	D.Drying/processing
5	E.Sorting, grading and quality checking 
6	F.Packaging (bottling, canning, hermetic plastic/treated bagging etc.) for selling or storage
7	G.Labeling 
8	H.Certification (local or international standard) 
9	I.Others (specify) 
99	J.None
*/

**From 2. Misizi_PE_Indicator_Analysis.do

egen value_chain_sum=rowtotal(value_chain1 - value_chain10) if D104==1
recode value_chain_sum (1/10=0) if value_chain10==1

gen value_chain_atl1=value_chain_sum
recode value_chain_atl1 (0=0) (1/9=1)

gen value_chain_atl3=value_chain_sum
recode value_chain_atl3 (0/2=0) (3/9=1)

svy: mean value_chain1 value_chain2 value_chain3 value_chain4 value_chain5 value_chain6 ///
          value_chain7 value_chain8 value_chain9 value_chain10, over(sample_type)

svy: mean value_chain1 value_chain2 value_chain3 value_chain4 value_chain5 value_chain6 ///
          value_chain7 value_chain8 value_chain9 value_chain10

forvalues i=1/10{
svy: mean value_chain`i', over(sample_type)
lincom [value_chain`i']Refugee - [value_chain`i']_subpop_2
}

svy: mean value_chain_atl1 value_chain_atl3, over(sample_type)
lincom [value_chain_atl1]Refugee - [value_chain_atl1]_subpop_2
lincom [value_chain_atl3]Refugee - [value_chain_atl3]_subpop_2

svy: mean value_chain_atl1 value_chain_atl3

**LIVESTOCK PRODUCTION
**% of households currently have livestock


forvalues i=1/12{
gen lvst_curr_`i'=0 if response==1
}

recode lvst_curr_1 (0=1) if E101A_A>0
recode lvst_curr_2 (0=1) if E101A_B>0
recode lvst_curr_3 (0=1) if E101A_C>0
recode lvst_curr_4 (0=1) if E101A_D>0
recode lvst_curr_5 (0=1) if E101A_E>0
recode lvst_curr_6 (0=1) if E101A_F>0
recode lvst_curr_7 (0=1) if E101A_G>0
recode lvst_curr_8 (0=1) if E101A_H>0
recode lvst_curr_9 (0=1) if E101A_I>0
recode lvst_curr_10 (0=1) if E101A_J>0
recode lvst_curr_11 (0=1) if E101A_K>0
recode lvst_curr_12 (0=1) if E101A_L>0


svy: mean lvst_curr_1 lvst_curr_2 lvst_curr_3 lvst_curr_4 lvst_curr_5 lvst_curr_6 lvst_curr_7 ///
		  lvst_curr_8 lvst_curr_9 lvst_curr_10 lvst_curr_11 lvst_curr_12, over(sample_type)
		  
svy: mean lvst_curr_1 lvst_curr_2 lvst_curr_3 lvst_curr_4 lvst_curr_5 lvst_curr_6 lvst_curr_7 ///
		  lvst_curr_8 lvst_curr_9 lvst_curr_10 lvst_curr_11 lvst_curr_12


forvalues i=1/12{
svy: mean lvst_curr_`i', over(sample_type)
lincom [lvst_curr_`i']Refugee - [lvst_curr_`i']_subpop_2
}

gen poultry_pigs_curr=0 if response==1
recode poultry_pigs_curr (0=1) if lvst_curr_6==1 | lvst_curr_7 | lvst_curr_8


svy: mean poultry_pigs_curr, over(sample_type)
lincom [poultry_pigs_curr]Refugee - [poultry_pigs_curr]_subpop_2

svy: mean poultry_pigs_curr


**% of households with any livestock

egen lvstk_curr_sum=rowtotal(lvst_curr_1 - lvst_curr_12) if response==1

tab lvstk_curr_sum

gen hh_any_lvstk=lvstk_curr_sum
recode hh_any_lvstk (0=0) (1/6=1)

svy: mean hh_any_lvstk, over(sample_type)
lincom [hh_any_lvstk]Refugee - [hh_any_lvstk]_subpop_2

svy: mean hh_any_lvstk








*Misizi/IKEA PROJECT SUPPORT ON LIVESTOCK PRODUCTION
*% of households received supports from Misizi Marshland/IKEA project on livestock prodcution

forvalues i=1/12{
gen livstk_supprt_`i'=0 if lvst_curr_`i'==1
}

recode livstk_supprt_1 (0=1) if E101B_A==1 
recode livstk_supprt_2 (0=1) if E101B_B==1
recode livstk_supprt_3 (0=1) if E101B_C==1 
recode livstk_supprt_4 (0=1) if E101B_D==1 
recode livstk_supprt_5 (0=1) if E101B_E==1 
recode livstk_supprt_6 (0=1) if E101B_F==1 
recode livstk_supprt_7 (0=1) if E101B_G==1 
recode livstk_supprt_8 (0=1) if E101B_H==1 
recode livstk_supprt_9 (0=1) if E101B_I==1 
recode livstk_supprt_10 (0=1) if E101B_J==1 
recode livstk_supprt_11 (0=1) if E101B_K==1 
recode livstk_supprt_12 (0=1) if E101B_L==1  



svy: mean livstk_supprt_2, over(sample_type)
lincom [livstk_supprt_2]Refugee - [livstk_supprt_2]_subpop_2

svy: mean livstk_supprt_3, over(sample_type)
lincom [livstk_supprt_3]Refugee - [livstk_supprt_3]_subpop_2

svy: mean livstk_supprt_4, over(sample_type)
lincom [livstk_supprt_4]Refugee - [livstk_supprt_4]_subpop_2

svy: mean livstk_supprt_5, over(sample_type)
lincom [livstk_supprt_5]Refugee - [livstk_supprt_5]_subpop_2

svy: mean livstk_supprt_6, over(sample_type)
lincom [livstk_supprt_6]Refugee - [livstk_supprt_6]_subpop_2

svy: mean livstk_supprt_8, over(sample_type)
lincom [livstk_supprt_8]Refugee - [livstk_supprt_8]_subpop_2

svy: mean livstk_supprt_9, over(sample_type)
lincom [livstk_supprt_9]Refugee - [livstk_supprt_9]_subpop_2

svy: mean livstk_supprt_11, over(sample_type)
lincom [livstk_supprt_11]Refugee - [livstk_supprt_11]_subpop_2


svy: mean livstk_supprt_2
svy: mean livstk_supprt_3
svy: mean livstk_supprt_4
svy: mean livstk_supprt_5
svy: mean livstk_supprt_6
svy: mean livstk_supprt_8
svy: mean livstk_supprt_9
svy: mean livstk_supprt_11

egen hh_any_lvst_sprt_sum=rowtotal(livstk_supprt_1 - livstk_supprt_12) if hh_any_lvstk==1

tab hh_any_lvst_sprt_sum

gen hh_any_lvst_sprt=hh_any_lvst_sprt_sum
recode hh_any_lvst_sprt (0=0) (1/2=1)

svy: mean hh_any_lvst_sprt, over(sample_type)
lincom [hh_any_lvst_sprt]Refugee - [hh_any_lvst_sprt]_subpop_2

svy: mean hh_any_lvst_sprt

tabulate hh_any_lvst_sprt sample_type


**% of households with poultry/pigs received assistance from Misizi/IKEA project

egen hh_poultry_pigs_sprt_sum=rowtotal(livstk_supprt_6 - livstk_supprt_8) if poultry_pigs_curr==1

tab hh_poultry_pigs_sprt_sum

gen hh_poultry_pigs_sprt=hh_poultry_pigs_sprt_sum
recode hh_poultry_pigs_sprt (0=0) (1/2=1)

svy: mean hh_poultry_pigs_sprt, over(sample_type)
lincom [hh_poultry_pigs_sprt]Refugee - [hh_poultry_pigs_sprt]_subpop_2

svy: mean hh_poultry_pigs_sprt

tabulate poultry_pigs_curr sample_type

**% of households with types of supports received from Misizi Marshland/IKEA project on livestock prodcution

hh_any_lvst_sprt

tab1 E102_*

/*
1	A.Livestock inputs (animal/poultry, fodder, medicine etc.)
2	B.Livestock production tools/equipment/shelter
3	C.Cash grant/voucher for start-up
4	D.In-kind support for start-up
5	E.Training on improved livestock practices and technologies 
6	F.Livestock production group formation/access to cooperatives/associations 
7	G.Support accessing to the markets or buyers for selling livestock/products
8	H.Support accessing to the markets or local suppliers to buy livestock inputs
9	I.Livestock employment/labor supports
10	J.Others (specify)
*/

forvalues i=1/10{
gen lvstk_sprt_types`i'=0 if hh_any_lvst_sprt==1
recode lvstk_sprt_types`i' (0=1) if E102_1==`i' | E102_2==`i' | E102_3==`i' | E102_4==`i' | E102_5==`i' ///
									 | E102_6==`i' | E102_7==`i' | E102_8==`i' | E102_9==`i' | E102_10==`i'
}




forvalues i=1/10{
svy: mean lvstk_sprt_types`i', over(sample_type)
lincom [lvstk_sprt_types`i']Refugee - [lvstk_sprt_types`i']_subpop_2
}


svy: mean lvstk_sprt_types1 lvstk_sprt_types2 lvstk_sprt_types3 lvstk_sprt_types4 lvstk_sprt_types5 lvstk_sprt_types6 ///
			lvstk_sprt_types7 lvstk_sprt_types8 lvstk_sprt_types9 lvstk_sprt_types10
			
tab E103			
			
			
*% of households sold livestock in the past 12 months		

gen sold_lvstk_12m=E103
recode sold_lvstk_12m (2=0)


svy: mean sold_lvstk_12m, over(sample_type)
lincom [sold_lvstk_12m]Refugee - [sold_lvstk_12m]_subpop_2

svy: mean sold_lvstk_12m

**% of households with the use of income from selling livestock in the past 12 months 


/*
1	A.Reinvestment for agriculture/livelihood/fish production activities (buying inputs: seeds, fertilizer, tools, labor, start-up livestock, fingerlings etc.) 
2	B.For household consumption (food, clothing, energy etc.)
3	C.Paid children’s school fees/education expenses
4	D.Paid for health insurance premium
5	E.Used to start new business
6	F.Used for household emergency need
7	G.Others (specify) 
*/

forvalues i=1/7{
gen lvstk_use_selling`i'=0 if sold_lvstk_12m==1
recode lvstk_use_selling`i' (0=1) if E104_1==`i' | E104_2==`i' | E104_3==`i' | E104_4==`i' | E104_5==`i' | E104_6==`i' | E104_7==`i'	
}			

tab1 lvstk_use_selling*

svy: mean lvstk_use_selling1 lvstk_use_selling2 lvstk_use_selling3 lvstk_use_selling4 ///
           lvstk_use_selling5 lvstk_use_selling6 lvstk_use_selling7, over(sample_type)


svy: mean lvstk_use_selling1 lvstk_use_selling2 lvstk_use_selling3 lvstk_use_selling4 ///
           lvstk_use_selling5 lvstk_use_selling6 lvstk_use_selling7


forvalues i=1/7{
svy: mean lvstk_use_selling`i', over(sample_type)
lincom [lvstk_use_selling`i']Refugee - [lvstk_use_selling`i']_subpop_2
}

tabulate sold_lvstk_12m sample_type

***MODULE-F: ACCESS TO MARKETS 

**Distance of the closest market

tab1 F101 F102

gen dist_clos_markt=0 if response==1
replace dist_clos_markt=1 if F101>=0 & F101<6 


svy: mean dist_clos_markt, over(sample_type)
lincom [dist_clos_markt]Refugee - [dist_clos_markt]_subpop_2

svy: mean dist_clos_markt

forvalues i=1/5{
gen clst_mrkt_type`i'=0 if dist_clos_markt==1
recode clst_mrkt_type`i' (0=1) if F102==`i'
}

tab1 clst_mrkt_type*

svy: mean clst_mrkt_type1 clst_mrkt_type2 clst_mrkt_type3 clst_mrkt_type4 clst_mrkt_type5, over(sample_type)
lincom [clst_mrkt_type1]Refugee - [clst_mrkt_type1]_subpop_2
lincom [clst_mrkt_type2]Refugee - [clst_mrkt_type2]_subpop_2
lincom [clst_mrkt_type3]Refugee - [clst_mrkt_type3]_subpop_2
lincom [clst_mrkt_type4]Refugee - [clst_mrkt_type4]_subpop_2
lincom [clst_mrkt_type5]Refugee - [clst_mrkt_type5]_subpop_2


svy: mean clst_mrkt_type1 clst_mrkt_type2 clst_mrkt_type3 clst_mrkt_type4 clst_mrkt_type5
			
tabulate dist_clos_markt sample_type

**% of households with the status of accessing to the main market to buy and sell agricultural/livestock products

tab F103

forvalues i=1/4{
gen accss_main_mrkt`i'=0 if response==1
recode accss_main_mrkt`i'(0=1) if F103==`i'
}

tab1 accss_main_mrkt*


svy: mean accss_main_mrkt1 accss_main_mrkt2 accss_main_mrkt3 accss_main_mrkt4, over(sample_type)
lincom [accss_main_mrkt1]Refugee - [accss_main_mrkt1]_subpop_2
lincom [accss_main_mrkt2]Refugee - [accss_main_mrkt2]_subpop_2
lincom [accss_main_mrkt3]Refugee - [accss_main_mrkt3]_subpop_2
lincom [accss_main_mrkt4]Refugee - [accss_main_mrkt4]_subpop_2

svy: mean accss_main_mrkt1 accss_main_mrkt2 accss_main_mrkt3 accss_main_mrkt4

tab1 F104_*

/*
1	A.Special markets including processing companies, collection centers, farmer’s group marketing etc.
2	B.Regular markets (Supermarket, Grocery chain, Retailer etc.)
3	C.Daily markets
4	D.Weekly markets
5	E.Monthly markets 
6	F.At my house or next to a road 
7	G.My household does not sell agriculture/livestock products 
*/

forvalues i=1/7{
gen selling_markt_typ_`i'=0 if response==1
recode selling_markt_typ_`i' (0=1) if F104_1==`i' | F104_2==`i' | F104_3==`i' | F104_4==`i' | F104_5==`i' | F104_6==`i' | F104_7==`i'
}


svy: mean selling_markt_typ_1 selling_markt_typ_2 selling_markt_typ_3 selling_markt_typ_4 selling_markt_typ_5 selling_markt_typ_6 selling_markt_typ_7, over(sample_type)
lincom [selling_markt_typ_1]Refugee - [selling_markt_typ_1]_subpop_2
lincom [selling_markt_typ_2]Refugee - [selling_markt_typ_2]_subpop_2
lincom [selling_markt_typ_3]Refugee - [selling_markt_typ_3]_subpop_2
lincom [selling_markt_typ_4]Refugee - [selling_markt_typ_4]_subpop_2
lincom [selling_markt_typ_5]Refugee - [selling_markt_typ_5]_subpop_2
lincom [selling_markt_typ_6]Refugee - [selling_markt_typ_6]_subpop_2
lincom [selling_markt_typ_7]Refugee - [selling_markt_typ_7]_subpop_2

svy: mean selling_markt_typ_1 selling_markt_typ_2 selling_markt_typ_3 selling_markt_typ_4 selling_markt_typ_5 selling_markt_typ_6 selling_markt_typ_7

*% of households with preferred (ranked 1) markets for selling agricultural/livestock products

egen selling_markt_typ_sum=rowtotal(selling_markt_typ_1 - selling_markt_typ_7) if response==1

tab selling_markt_typ_sum
recode selling_markt_typ_sum (1/4=0) if selling_markt_typ_7==1
gen selling_markt_typ=selling_markt_typ_sum
recode selling_markt_typ (0=0) (1/4=1)

tab selling_markt_typ


gen F105r_1=F105A
gen F105r_2=F105B
gen F105r_3=F105C
gen F105r_4=F105D
gen F105r_5=F105E
gen F105r_6=F105F



forvalues i=1/6{
gen rank_mrkt_sell_`i'=0 if selling_markt_typ==1
recode rank_mrkt_sell_`i' (0=1) if F105r_`i'==1
}

svy: mean rank_mrkt_sell_1 rank_mrkt_sell_2 rank_mrkt_sell_3 rank_mrkt_sell_4 rank_mrkt_sell_5 rank_mrkt_sell_6, over(sample_type)
lincom [rank_mrkt_sell_1]Refugee - [rank_mrkt_sell_1]_subpop_2
lincom [rank_mrkt_sell_2]Refugee - [rank_mrkt_sell_2]_subpop_2
lincom [rank_mrkt_sell_3]Refugee - [rank_mrkt_sell_3]_subpop_2
lincom [rank_mrkt_sell_4]Refugee - [rank_mrkt_sell_4]_subpop_2
lincom [rank_mrkt_sell_5]Refugee - [rank_mrkt_sell_5]_subpop_2
lincom [rank_mrkt_sell_6]Refugee - [rank_mrkt_sell_6]_subpop_2

svy: mean rank_mrkt_sell_1 rank_mrkt_sell_2 rank_mrkt_sell_3 rank_mrkt_sell_4 rank_mrkt_sell_5 rank_mrkt_sell_6

tabulate selling_markt_typ sample_type

**MODULE-G: ACCESS TO FINANCIAL SERVICES

*ACCESS TO SAVINGS

*% households with family members currently have cash savings

tab G101

gen hh_curr_savings=0 if response==1
recode hh_curr_savings (0=1) if G101==1

svy: mean hh_curr_savings, over(sample_type)
lincom [hh_curr_savings]Refugee - [hh_curr_savings]_subpop_2

svy: mean hh_curr_savings

**% of households with savings by gender

tab1 G102A G102B

tabulate hh_curr_savings sample_type

gen savings_male=0 if hh_curr_savings==1
recode savings_male (0=1) if G102A>0 & G102B==0

gen savings_female=0 if hh_curr_savings==1
recode savings_female (0=1) if G102B>0 & G102A==0

gen savings_male_female=0 if hh_curr_savings==1
recode savings_male_female (0=1) if G102B>0 & G102A>0


tab1 savings_male savings_female savings_male_female


svy: mean savings_male savings_female savings_male_female, over(sample_type)
lincom [savings_male]Refugee - [savings_male]_subpop_2
lincom [savings_female]Refugee - [savings_female]_subpop_2
lincom [savings_male_female]Refugee - [savings_male_female]_subpop_2

svy: mean savings_male savings_female savings_male_female

*% of households with place of savings

forvalues i=1/6{
gen savings_place`i'=0 if hh_curr_savings==1
recode savings_place`i' (0=1) if G103A1==`i' | G103A2==`i' | G103A3==`i' | G103A4==`i' | G103A5==`i' | G103A6==`i' | G103A7==`i'
}

svy: mean savings_place1 savings_place2 savings_place3 savings_place4 savings_place5 savings_place6, over(sample_type)
lincom [savings_place1]Refugee - [savings_place1]_subpop_2
lincom [savings_place2]Refugee - [savings_place2]_subpop_2
lincom [savings_place3]Refugee - [savings_place3]_subpop_2
lincom [savings_place4]Refugee - [savings_place4]_subpop_2
lincom [savings_place5]Refugee - [savings_place5]_subpop_2
lincom [savings_place6]Refugee - [savings_place6]_subpop_2

svy: mean savings_place1 savings_place2 savings_place3 savings_place4 savings_place5 savings_place6

**% of households with who supported/assited for cash savings in the places:

G103B_A
G103B_B
G103B_C
G103B_D
G103B_E
G103B_F

foreach x in A B C D E F{
forvalues i=1/3{
gen G103B_`x'r`i'=G103B_`x'`i'
}
}

foreach x in A B C D E F{
forvalues i=1/3{
recode G103B_`x'r`i' (9=3)
}
}


forvalues i=1/3{
gen save_asst_A_`i'=0 if savings_place1==1
recode save_asst_A_`i' (0=1) if G103B_Ar1==`i' | G103B_Ar2==`i' | G103B_Ar3==`i'
}

forvalues i=1/3{
gen save_asst_B_`i'=0 if savings_place2==1
recode save_asst_B_`i' (0=1) if G103B_Br1==`i' | G103B_Br2==`i' | G103B_Br3==`i'
}

forvalues i=1/3{
gen save_asst_C_`i'=0 if savings_place3==1
recode save_asst_C_`i' (0=1) if G103B_Cr1==`i' | G103B_Cr2==`i' | G103B_Cr3==`i'
}

forvalues i=1/3{
gen save_asst_D_`i'=0 if savings_place4==1
recode save_asst_D_`i' (0=1) if G103B_Dr1==`i' | G103B_Dr2==`i' | G103B_Dr3==`i'
}

forvalues i=1/3{
gen save_asst_E_`i'=0 if savings_place5==1
recode save_asst_E_`i' (0=1) if G103B_Er1==`i' | G103B_Er2==`i' | G103B_Er3==`i'
}


forvalues i=1/3{
gen save_asst_F_`i'=0 if savings_place6==1
recode save_asst_F_`i' (0=1) if G103B_Fr1==`i' | G103B_Fr2==`i' | G103B_Fr3==`i'
}


svy: mean save_asst_A_1 save_asst_A_2 save_asst_A_3, over(sample_type)
lincom [save_asst_A_1]Refugee - [save_asst_A_1]_subpop_2
lincom [save_asst_A_2]Refugee - [save_asst_A_2]_subpop_2
lincom [save_asst_A_3]Refugee - [save_asst_A_3]_subpop_2

svy: mean save_asst_A_1 save_asst_A_2 save_asst_A_3


svy: mean save_asst_B_1 save_asst_B_2 save_asst_B_3, over(sample_type)
lincom [save_asst_B_1]Refugee - [save_asst_B_1]_subpop_2
lincom [save_asst_B_2]Refugee - [save_asst_B_2]_subpop_2
lincom [save_asst_B_3]Refugee - [save_asst_B_3]_subpop_2

svy: mean save_asst_B_1 save_asst_B_2 save_asst_B_3


svy: mean save_asst_C_1 save_asst_C_2 save_asst_C_3, over(sample_type)
lincom [save_asst_C_1]Refugee - [save_asst_C_1]_subpop_2
lincom [save_asst_C_2]Refugee - [save_asst_C_2]_subpop_2
lincom [save_asst_C_3]Refugee - [save_asst_C_3]_subpop_2

svy: mean save_asst_C_1 save_asst_C_2 save_asst_C_3


svy: mean save_asst_D_1 save_asst_D_2 save_asst_D_3, over(sample_type)
lincom [save_asst_D_1]Refugee - [save_asst_D_1]_subpop_2
lincom [save_asst_D_2]Refugee - [save_asst_D_2]_subpop_2
lincom [save_asst_D_3]Refugee - [save_asst_D_3]_subpop_2

svy: mean save_asst_D_1 save_asst_D_2 save_asst_D_3


svy: mean save_asst_E_1 save_asst_E_2 save_asst_E_3, over(sample_type)
lincom [save_asst_E_1]Refugee - [save_asst_E_1]_subpop_2
lincom [save_asst_E_2]Refugee - [save_asst_E_2]_subpop_2
lincom [save_asst_E_3]Refugee - [save_asst_E_3]_subpop_2

svy: mean save_asst_E_1 save_asst_E_2 save_asst_E_3


svy: mean save_asst_F_1 save_asst_F_2 save_asst_F_3, over(sample_type)
lincom [save_asst_F_1]Refugee - [save_asst_F_1]_subpop_2
lincom [save_asst_F_2]Refugee - [save_asst_F_2]_subpop_2
lincom [save_asst_F_3]Refugee - [save_asst_F_3]_subpop_2

svy: mean save_asst_F_1 save_asst_F_2 save_asst_F_3

tabulate savings_place1 sample_type
tabulate savings_place2 sample_type
tabulate savings_place3 sample_type
tabulate savings_place4 sample_type
tabulate savings_place5 sample_type
tabulate savings_place6 sample_type

**% of households with the purposes of savings

/*
1	A.To reinvest in agricultural production activities
2	B.To reinvest for livestock production activities
3	C.To reinvest fish farming activities
4	D.To reinvest agricultural/livestock business
5	E.To reinvest non-agricultural/livestock business
6	F.To start a new business 
7	G.To meet educational expenses
8	H.To use for health insurance
9	I.To use for household emergency needs (food, treatment cost, shocks,  house repair, etc.) 
10	J.To use for loan repayment
11	K.To use for social events (wedding, funeral etc.) 
12	L.Others (specify)
99	M.Don’t know
*/

tab1 G104*

forvalues i=1/13{
gen G104r_`i'=G104_`i'
recode G104r_`i' (99=13)
}

forvalues i=1/13{
gen savings_purp_`i'=0 if hh_curr_savings==1
recode savings_purp_`i' (0=1) if G104r_1==`i' | G104r_2==`i' | G104r_3==`i' | G104r_4==`i' | G104r_5==`i' | G104r_6==`i' ///
								 | G104r_7==`i' | G104r_8==`i' | G104r_9==`i' | G104r_10==`i' | G104r_11==`i' | G104r_12==`i' | G104r_13==`i' 
}


tab1 savings_purp_*

svy: mean savings_purp_1 savings_purp_2 savings_purp_3 savings_purp_4 savings_purp_5 savings_purp_6 savings_purp_7 ///
		  savings_purp_8 savings_purp_9 savings_purp_10 savings_purp_11 savings_purp_12 savings_purp_13, over (sample_type)
		  
svy: mean savings_purp_1 savings_purp_2 savings_purp_3 savings_purp_4 savings_purp_5 savings_purp_6 savings_purp_7 ///
		  savings_purp_8 savings_purp_9 savings_purp_10 savings_purp_11 savings_purp_12 savings_purp_13

forvalues i=1/13{
svy: mean savings_purp_`i', over(sample_type)
lincom [savings_purp_`i']Refugee - [savings_purp_`i']_subpop_2
}

**ACCESS TO CREDITS
*% households with family members currently have loans


tab G105

gen hh_curr_credtis=0 if response==1
recode hh_curr_credtis (0=1) if G105==1

svy: mean hh_curr_credtis, over(sample_type)
lincom [hh_curr_credtis]Refugee - [hh_curr_credtis]_subpop_2

svy: mean hh_curr_credtis

**% of households with credits by gender

tab1 G106A G106B

tabulate hh_curr_credtis sample_type

gen credits_male=0 if hh_curr_credtis==1
recode credits_male (0=1) if G106A>0 & G106B==0

gen credits_female=0 if hh_curr_credtis==1
recode credits_female (0=1) if G106B>0 & G106A==0

gen credits_male_female=0 if hh_curr_credtis==1
recode credits_male_female (0=1) if G106B>0 & G106A>0


tab1 credits_male credits_female credits_male_female


svy: mean credits_male credits_female credits_male_female, over(sample_type)
lincom [credits_male]Refugee - [credits_male]_subpop_2
lincom [credits_female]Refugee - [credits_female]_subpop_2
lincom [credits_male_female]Refugee - [credits_male_female]_subpop_2

svy: mean credits_male credits_female credits_male_female


*% of households with place of loans

forvalues i=1/8{
gen credits_place`i'=0 if hh_curr_credtis==1
recode credits_place`i' (0=1) if G107A1==`i' | G107A2==`i' | G107A3==`i' | G107A4==`i' | G107A5==`i' | G107A6==`i' | G107A7==`i' | G107A8==`i'
}

svy: mean credits_place1 credits_place2 credits_place3 credits_place4 credits_place5 credits_place6 credits_place7 credits_place8, over(sample_type)
lincom [credits_place1]Refugee - [credits_place1]_subpop_2
lincom [credits_place2]Refugee - [credits_place2]_subpop_2
lincom [credits_place3]Refugee - [credits_place3]_subpop_2
lincom [credits_place4]Refugee - [credits_place4]_subpop_2
lincom [credits_place5]Refugee - [credits_place5]_subpop_2
lincom [credits_place6]Refugee - [credits_place6]_subpop_2
lincom [credits_place7]Refugee - [credits_place7]_subpop_2
lincom [credits_place8]Refugee - [credits_place8]_subpop_2

svy: mean credits_place1 credits_place2 credits_place3 credits_place4 credits_place5 credits_place6 credits_place7 credits_place8

*% of households with who supported/assited for loans in the places:

G107B_A
G107B_B
G107B_C
G107B_D
G107B_E
G107B_F
G107B_G
G107B_H


foreach x in A B C D E F G H{
forvalues i=1/3{
gen G107B_`x'r`i'=G107B_`x'`i'
}
}

foreach x in A B C D E F G H{
forvalues i=1/3{
recode G107B_`x'r`i' (9=3)
}
}


forvalues i=1/3{
gen credit_asst_A_`i'=0 if credits_place1==1
recode credit_asst_A_`i' (0=1) if G107B_Ar1==`i' | G107B_Ar2==`i' | G107B_Ar3==`i'
}

forvalues i=1/3{
gen credit_asst_B_`i'=0 if credits_place2==1
recode credit_asst_B_`i' (0=1) if G107B_Br1==`i' | G107B_Br2==`i' | G107B_Br3==`i'
}

forvalues i=1/3{
gen credit_asst_C_`i'=0 if credits_place3==1
recode credit_asst_C_`i' (0=1) if G107B_Cr1==`i' | G107B_Cr2==`i' | G107B_Cr3==`i'
}

forvalues i=1/3{
gen credit_asst_D_`i'=0 if credits_place4==1
recode credit_asst_D_`i' (0=1) if G107B_Dr1==`i' | G107B_Dr2==`i' | G107B_Dr3==`i'
}

forvalues i=1/3{
gen credit_asst_E_`i'=0 if credits_place5==1
recode credit_asst_E_`i' (0=1) if G107B_Er1==`i' | G107B_Er2==`i' | G107B_Er3==`i'
}

forvalues i=1/3{
gen credit_asst_F_`i'=0 if credits_place6==1
recode credit_asst_F_`i' (0=1) if G107B_Fr1==`i' | G107B_Fr2==`i' | G107B_Fr3==`i'
}


forvalues i=1/3{
gen credit_asst_G_`i'=0 if credits_place7==1
recode credit_asst_G_`i' (0=1) if G107B_Gr1==`i' | G107B_Gr2==`i' | G107B_Gr3==`i'
}

forvalues i=1/3{
gen credit_asst_H_`i'=0 if credits_place8==1
recode credit_asst_H_`i' (0=1) if G107B_Hr1==`i' | G107B_Hr2==`i' | G107B_Hr3==`i'
}



svy: mean credit_asst_A_1 credit_asst_A_2 credit_asst_A_3, over(sample_type)
lincom [credit_asst_A_1]Refugee - [credit_asst_A_1]_subpop_2
lincom [credit_asst_A_2]Refugee - [credit_asst_A_2]_subpop_2
lincom [credit_asst_A_3]Refugee - [credit_asst_A_3]_subpop_2

svy: mean credit_asst_A_1 credit_asst_A_2 credit_asst_A_3

svy: mean credit_asst_B_1 credit_asst_B_2 credit_asst_B_3, over(sample_type)
lincom [credit_asst_B_1]Refugee - [credit_asst_B_1]_subpop_2
lincom [credit_asst_B_2]Refugee - [credit_asst_B_2]_subpop_2
lincom [credit_asst_B_3]Refugee - [credit_asst_B_3]_subpop_2

svy: mean credit_asst_B_1 credit_asst_B_2 credit_asst_B_3


svy: mean credit_asst_C_1 credit_asst_C_2 credit_asst_C_3, over(sample_type)
lincom [credit_asst_C_1]Refugee - [credit_asst_C_1]_subpop_2
lincom [credit_asst_C_2]Refugee - [credit_asst_C_2]_subpop_2
lincom [credit_asst_C_3]Refugee - [credit_asst_C_3]_subpop_2

svy: mean credit_asst_C_1 credit_asst_C_2 credit_asst_C_3


svy: mean credit_asst_D_1 credit_asst_D_2 credit_asst_D_3, over(sample_type)
lincom [credit_asst_D_1]Refugee - [credit_asst_D_1]_subpop_2
lincom [credit_asst_D_2]Refugee - [credit_asst_D_2]_subpop_2
lincom [credit_asst_D_3]Refugee - [credit_asst_D_3]_subpop_2

svy: mean credit_asst_D_1 credit_asst_D_2 credit_asst_D_3

svy: mean credit_asst_E_1 credit_asst_E_2 credit_asst_E_3, over(sample_type)
lincom [credit_asst_E_1]Refugee - [credit_asst_E_1]_subpop_2
lincom [credit_asst_E_2]Refugee - [credit_asst_E_2]_subpop_2
lincom [credit_asst_E_3]Refugee - [credit_asst_E_3]_subpop_2

svy: mean credit_asst_E_1 credit_asst_E_2 credit_asst_E_3

svy: mean credit_asst_F_1 credit_asst_F_2 credit_asst_F_3, over(sample_type)
lincom [credit_asst_F_1]Refugee - [credit_asst_F_1]_subpop_2
lincom [credit_asst_F_2]Refugee - [credit_asst_F_2]_subpop_2
lincom [credit_asst_F_3]Refugee - [credit_asst_F_3]_subpop_2

svy: mean credit_asst_F_1 credit_asst_F_2 credit_asst_F_3

svy: mean credit_asst_G_1 credit_asst_G_2 credit_asst_G_3, over(sample_type)
lincom [credit_asst_G_1]Refugee - [credit_asst_G_1]_subpop_2
lincom [credit_asst_G_2]Refugee - [credit_asst_G_2]_subpop_2
lincom [credit_asst_G_3]Refugee - [credit_asst_G_3]_subpop_2

svy: mean credit_asst_G_1 credit_asst_G_2 credit_asst_G_3

svy: mean credit_asst_H_1 credit_asst_H_2 credit_asst_H_3, over(sample_type)
lincom [credit_asst_H_1]Refugee - [credit_asst_H_1]_subpop_2
lincom [credit_asst_H_2]Refugee - [credit_asst_H_2]_subpop_2
lincom [credit_asst_H_3]Refugee - [credit_asst_H_3]_subpop_2

svy: mean credit_asst_H_1 credit_asst_H_2 credit_asst_H_3



tabulate credits_place1 sample_type
tabulate credits_place2 sample_type
tabulate credits_place3 sample_type
tabulate credits_place4 sample_type
tabulate credits_place5 sample_type
tabulate credits_place6 sample_type
tabulate credits_place7 sample_type
tabulate credits_place8 sample_type

**% of households with the purposes of loans

tab1 G108*

forvalues i=1/12{
gen G108r_`i'=G108_`i'
recode G108r_`i' (99=12)
}

forvalues i=1/12{
gen credit_purp_`i'=0 if hh_curr_credtis==1
recode credit_purp_`i' (0=1) if G108r_1==`i' | G108r_2==`i' | G108r_3==`i' | G108r_4==`i' | G108r_5==`i' | G108r_6==`i' ///
								 | G108r_7==`i' | G108r_8==`i' | G108r_9==`i' | G108r_10==`i' | G108r_11==`i' | G108r_12==`i' 
}


tab1 credit_purp_*

svy: mean credit_purp_1 credit_purp_2 credit_purp_3 credit_purp_4 credit_purp_5 credit_purp_6 credit_purp_7 ///
		  credit_purp_8 credit_purp_9 credit_purp_10 credit_purp_11 credit_purp_12, over (sample_type)
		  
svy: mean credit_purp_1 credit_purp_2 credit_purp_3 credit_purp_4 credit_purp_5 credit_purp_6 credit_purp_7 ///
		  credit_purp_8 credit_purp_9 credit_purp_10 credit_purp_11 credit_purp_12

forvalues i=1/12{
svy: mean credit_purp_`i', over(sample_type)
lincom [credit_purp_`i']Refugee - [credit_purp_`i']_subpop_2
}


**MODULE-H: SOCIAL CAPITAL AND SOCIAL COHESION
**FORMAL SAFETYNETS

**% of HHs with HH members involved in community groups/associations


/*
1	A.Microfinance institution (MFI)/ Cooperatives/ Credit Unions
2	B.Savings groups, such as, tontine, rotating organization of savings and credit association (ROSCA), village savings and loans association (VSLA) 
3	C.Cooperative/association of individuals working together
4	D.Social groups, such as, religious group, natural resources management group, social protection group etc.
5	E.Other groups/associations (specify)
9	F.None
*/


tab1 H101A*

forvalues i=1/6{
gen H101Ar`i'=H101A`i'
}

forvalues i=1/6{
recode H101Ar`i' (9=6)
}

forvalues i=1/6{
gen fomal_saftyn`i'=0 if response==1
recode fomal_saftyn`i'(0=1) if H101Ar1==`i' | H101Ar2==`i' | H101Ar3==`i' | H101Ar4==`i' | H101Ar5==`i' | H101Ar6==`i'
}

svy: mean fomal_saftyn1 fomal_saftyn2 fomal_saftyn3 fomal_saftyn4 fomal_saftyn5 fomal_saftyn6, over (sample_type)
svy: mean fomal_saftyn1 fomal_saftyn2 fomal_saftyn3 fomal_saftyn4 fomal_saftyn5 fomal_saftyn6

forvalues i=1/6{
svy: mean fomal_saftyn`i', over(sample_type)
lincom [fomal_saftyn`i']Refugee - [fomal_saftyn`i']_subpop_2
}

egen acc_formal_safetynet_sum=rowtotal(fomal_saftyn1 - fomal_saftyn5) if response==1

gen acc_formal_safetynet=acc_formal_safetynet_sum
recode acc_formal_safetynet (0=0) (1/4=1)

svy: mean acc_formal_safetynet, over (sample_type)
lincom [acc_formal_safetynet]Refugee - [acc_formal_safetynet]_subpop_2

svy: mean acc_formal_safetynet

**% of households with supports from Misizi project to join on the social groups/networks


gen acc_frml_sftynt_misizi1=0 if response==1
recode acc_frml_sftynt_misizi1 (0=1) if H101B_A1==1 | H101B_A2==1 | H101B_A3==1

gen acc_frml_sftynt_misizi2=0 if response==1
recode acc_frml_sftynt_misizi2 (0=1) if H101B_B1==1 | H101B_B2==1 | H101B_B3==1

gen acc_frml_sftynt_misizi3=0 if response==1
recode acc_frml_sftynt_misizi3 (0=1) if H101B_C1==1 | H101B_C2==1 | H101B_C3==1

gen acc_frml_sftynt_misizi4=0 if response==1
recode acc_frml_sftynt_misizi4 (0=1) if H101B_D1==1 | H101B_D2==1 | H101B_D3==1

gen acc_frml_sftynt_misizi5=0 if response==1
recode acc_frml_sftynt_misizi5 (0=1) if H101B_E1==1 | H101B_E2==1 | H101B_E3==1


svy: mean acc_frml_sftynt_misizi1 acc_frml_sftynt_misizi2 acc_frml_sftynt_misizi3 acc_frml_sftynt_misizi4 acc_frml_sftynt_misizi5, over (sample_type)
svy: mean acc_frml_sftynt_misizi1 acc_frml_sftynt_misizi2 acc_frml_sftynt_misizi3 acc_frml_sftynt_misizi4 acc_frml_sftynt_misizi5

forvalues i=1/5{
svy: mean acc_frml_sftynt_misizi`i', over(sample_type)
lincom [acc_frml_sftynt_misizi`i']Refugee - [acc_frml_sftynt_misizi`i']_subpop_2
}

egen acc_frml_sftynt_misizi_sum=rowtotal(acc_frml_sftynt_misizi1 - acc_frml_sftynt_misizi5) if response==1
gen acc_frml_sftynt_misizi=acc_frml_sftynt_misizi_sum
recode acc_frml_sftynt_misizi (0=0) (1/2=1)


svy: mean acc_frml_sftynt_misizi, over (sample_type)
lincom [acc_frml_sftynt_misizi]Refugee - [acc_frml_sftynt_misizi]_subpop_2
svy: mean acc_frml_sftynt_misizi

**SOCIAL CAPITAL (INFORMAL, LINKING, BONDING, BRIDGING)

**INFORMAL



* % of HHs would be able to get help from various categories of people living WITHIN their community if they needed it

/* H102
1	A.Relatives
2	B.Non-relatives
3	C.No one
8	D.Don’t know
9	Refused
*/

forvalues i=1/5{
gen H102r_`i'=H102_`i'
recode H102r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen bond_recev`i'=0 if response==1
recode bond_recev`i' (0=1) if H102r_1==`i' | H102r_2==`i' | H102r_3==`i' | H102r_4==`i' | H102r_5==`i'
}

* % of HHs would be able to give help to people living WITHIN their community who needed it.

/* H105
1	A.Relatives
2	B.Non-relatives
3	C.No one
8	D.Don’t know
9	Refused
*/

forvalues i=1/5{
gen H105r_`i'=H105_`i'
recode H105r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen bond_give`i'=0 if response==1
recode bond_give`i' (0=1) if H105r_1==`i' | H105r_2==`i' | H105r_3==`i' | H105r_4==`i' | H105r_5==`i'
}

egen bonding_sum=rowtotal(bond_recev1 bond_recev2 bond_give1 bond_give2) if response==1

tab bonding_sum

egen bonding_max=max(bonding_sum)  
egen bonding_min=min(bonding_sum) 

gen bonding_index=(bonding_sum-bonding_min)*100/(bonding_max-bonding_min) 

tab bonding_index


svy: mean bond_recev1 bond_recev2 bond_recev3 bond_recev4 bond_recev5, over (sample_type)
lincom [bond_recev1]Refugee - [bond_recev1]_subpop_2
lincom [bond_recev2]Refugee - [bond_recev2]_subpop_2
lincom [bond_recev3]Refugee - [bond_recev3]_subpop_2
lincom [bond_recev4]Refugee - [bond_recev4]_subpop_2
lincom [bond_recev5]Refugee - [bond_recev5]_subpop_2

svy: mean bond_recev1 bond_recev2 bond_recev3 bond_recev4 bond_recev5

svy: mean bond_give1 bond_give2 bond_give3 bond_give4 bond_give5, over (sample_type)
lincom [bond_give1]Refugee - [bond_give1]_subpop_2
lincom [bond_give2]Refugee - [bond_give2]_subpop_2
lincom [bond_give3]Refugee - [bond_give3]_subpop_2
lincom [bond_give4]Refugee - [bond_give4]_subpop_2
lincom [bond_give5]Refugee - [bond_give5]_subpop_2

svy: mean bond_give1 bond_give2 bond_give3 bond_give4 bond_give5


svy: mean bonding_sum, over (sample_type)
lincom [bonding_sum]Refugee - [bonding_sum]_subpop_2

svy: mean bonding_sum

svy: mean bonding_index, over (sample_type)
lincom [bonding_index]Refugee - [bonding_index]_subpop_2

svy: mean bonding_index

egen bond_rece_w_sum=rowtotal(bond_recev1 bond_recev2) if response==1
gen bond_rece_w=bond_rece_w_sum
recode bond_rece_w (0=0) (1/2=1)

egen bond_give_w_sum=rowtotal(bond_give1 bond_give2) if response==1
gen bond_give_w=bond_give_w_sum
recode bond_give_w (0=0) (1/2=1)

svy: mean bond_rece_w, over (sample_type)
lincom [bond_rece_w]Refugee - [bond_rece_w]_subpop_2

svy: mean bond_rece_w

svy: mean bond_give_w, over (sample_type)
lincom [bond_give_w]Refugee - [bond_give_w]_subpop_2

svy: mean bond_give_w


**% of HHs received help from other households WITHIN their community in the past 12 months

forvalues i=1/5{
gen H108r_`i'=H108_`i'
recode H108r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen recvd_w_comm`i'=0 if response==1
recode recvd_w_comm`i' (0=1) if H108r_1==`i' | H108r_2==`i' | H108r_3==`i' | H108r_4==`i' | H108r_5==`i'
}

egen recvd_w_comm_sum=rowtotal(recvd_w_comm1 recvd_w_comm2) if response==1
gen recvd_w_comm=recvd_w_comm_sum
recode recvd_w_comm (0=0) (1/2=1)


svy: mean recvd_w_comm1 recvd_w_comm2 recvd_w_comm3 recvd_w_comm4 recvd_w_comm5, over (sample_type)
lincom [recvd_w_comm1]Refugee - [recvd_w_comm1]_subpop_2
lincom [recvd_w_comm2]Refugee - [recvd_w_comm2]_subpop_2
lincom [recvd_w_comm3]Refugee - [recvd_w_comm3]_subpop_2
lincom [recvd_w_comm4]Refugee - [recvd_w_comm4]_subpop_2
lincom [recvd_w_comm5]Refugee - [recvd_w_comm5]_subpop_2

svy: mean recvd_w_comm1 recvd_w_comm2 recvd_w_comm3 recvd_w_comm4 recvd_w_comm5

svy: mean recvd_w_comm, over (sample_type)
lincom [recvd_w_comm]Refugee - [recvd_w_comm]_subpop_2

svy: mean recvd_w_comm


**% of HHs helped other households WITHIN their community in the past 12 months

forvalues i=1/5{
gen H107r_`i'=H107_`i'
recode H107r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen helped_w_comm`i'=0 if response==1
recode helped_w_comm`i' (0=1) if H107r_1==`i' | H107r_2==`i' | H107r_3==`i' | H107r_4==`i' | H107r_5==`i'
}

egen helped_w_comm_sum=rowtotal(helped_w_comm1 helped_w_comm2) if response==1
gen helped_w_comm=helped_w_comm_sum
recode helped_w_comm (0=0) (1/2=1)


svy: mean helped_w_comm1 helped_w_comm2 helped_w_comm3 helped_w_comm4 helped_w_comm5, over (sample_type)
lincom [helped_w_comm1]Refugee - [helped_w_comm1]_subpop_2
lincom [helped_w_comm2]Refugee - [helped_w_comm2]_subpop_2
lincom [helped_w_comm3]Refugee - [helped_w_comm3]_subpop_2
lincom [helped_w_comm4]Refugee - [helped_w_comm4]_subpop_2
lincom [helped_w_comm5]Refugee - [helped_w_comm5]_subpop_2

svy: mean helped_w_comm1 helped_w_comm2 helped_w_comm3 helped_w_comm4 helped_w_comm5

svy: mean helped_w_comm, over (sample_type)
lincom [helped_w_comm]Refugee - [helped_w_comm]_subpop_2

svy: mean helped_w_comm


**Bridging H103 H106


* % of HHs would be able to get help from various categories of people living OUTSIDE community if the household needed it

/* H103
1	A.Relatives
2	B.Non-relatives
3	C.No one
8	D.Don’t know
9	Refused
*/

forvalues i=1/5{
gen H103r_`i'=H103_`i'
recode H103r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen bridge_recev`i'=0 if response==1
recode bridge_recev`i' (0=1) if H103r_1==`i' | H103r_2==`i' | H103r_3==`i' | H103r_4==`i' | H103r_5==`i'
}


egen bridge_recev_sum=rowtotal(bridge_recev1 bridge_recev2) if response==1
gen bridge_recev=bridge_recev_sum
recode bridge_recev (0=0) (1/2=1)

svy: mean bridge_recev, over (sample_type)
lincom [bridge_recev]Refugee - [bridge_recev]_subpop_2

svy: mean bridge_recev



* % of HHs would be able to give help to people living OUTSIDE their community who needed it.

/* H105
1	A.Relatives
2	B.Non-relatives
3	C.No one
8	D.Don’t know
9	Refused
*/

forvalues i=1/5{
gen H106r_`i'=H106_`i'
recode H106r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen bridge_give`i'=0 if response==1
recode bridge_give`i' (0=1) if H106r_1==`i' | H106r_2==`i' | H106r_3==`i' | H106r_4==`i' | H106r_5==`i'
}

egen bridge_sum=rowtotal(bridge_recev1 bridge_recev2 bridge_give1 bridge_give2) if response==1

tab bridge_sum

egen bridge_max=max(bridge_sum)  
egen bridge_min=min(bridge_sum) 

gen bridge_index=(bridge_sum-bridge_min)*100/(bridge_max-bridge_min) 

tab bridge_index



svy: mean bridge_recev1 bridge_recev2 bridge_recev3 bridge_recev4 bridge_recev5, over (sample_type)
lincom [bridge_recev1]Refugee - [bridge_recev1]_subpop_2
lincom [bridge_recev2]Refugee - [bridge_recev2]_subpop_2
lincom [bridge_recev3]Refugee - [bridge_recev3]_subpop_2
lincom [bridge_recev4]Refugee - [bridge_recev4]_subpop_2
lincom [bridge_recev5]Refugee - [bridge_recev5]_subpop_2

svy: mean bridge_recev1 bridge_recev2 bridge_recev3 bridge_recev4 bridge_recev5

svy: mean bridge_give1 bridge_give2 bridge_give3 bridge_give4 bridge_give5, over (sample_type)
lincom [bridge_give1]Refugee - [bridge_give1]_subpop_2
lincom [bridge_give2]Refugee - [bridge_give2]_subpop_2
lincom [bridge_give3]Refugee - [bridge_give3]_subpop_2
lincom [bridge_give4]Refugee - [bridge_give4]_subpop_2
lincom [bridge_give5]Refugee - [bridge_give5]_subpop_2

svy: mean bridge_give1 bridge_give2 bridge_give3 bridge_give4 bridge_give5


svy: mean bridge_sum, over (sample_type)
lincom [bridge_sum]Refugee - [bridge_sum]_subpop_2

svy: mean bridge_sum

svy: mean bridge_index, over (sample_type)
lincom [bridge_index]Refugee - [bridge_index]_subpop_2

svy: mean bridge_index


egen bridge_give_sum=rowtotal(bridge_give1 bridge_give2) if response==1
gen bridge_give=bridge_give_sum
recode bridge_give (0=0) (1/2=1)

svy: mean bridge_give, over (sample_type)
lincom [bridge_give]Refugee - [bridge_give]_subpop_2

svy: mean bridge_give

**% of HHs received help from other households OUTSIDE their community in the past 12 months

forvalues i=1/5{
gen H110r_`i'=H110_`i'
recode H110r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen recvd_out_comm`i'=0 if response==1
recode recvd_out_comm`i' (0=1) if H110r_1==`i' | H110r_2==`i' | H110r_3==`i' | H110r_4==`i' | H110r_5==`i'
}

egen recvd_out_comm_sum=rowtotal(recvd_out_comm1 recvd_out_comm2) if response==1
gen recvd_out_comm=recvd_out_comm_sum
recode recvd_out_comm (0=0) (1/2=1)


svy: mean recvd_out_comm1 recvd_out_comm2 recvd_out_comm3 recvd_out_comm4 recvd_out_comm5, over (sample_type)
lincom [recvd_out_comm1]Refugee - [recvd_out_comm1]_subpop_2
lincom [recvd_out_comm2]Refugee - [recvd_out_comm2]_subpop_2
lincom [recvd_out_comm3]Refugee - [recvd_out_comm3]_subpop_2
lincom [recvd_out_comm4]Refugee - [recvd_out_comm4]_subpop_2
lincom [recvd_out_comm5]Refugee - [recvd_out_comm5]_subpop_2

svy: mean recvd_out_comm1 recvd_out_comm2 recvd_out_comm3 recvd_out_comm4 recvd_out_comm5

svy: mean recvd_out_comm, over (sample_type)
lincom [recvd_out_comm]Refugee - [recvd_out_comm]_subpop_2

svy: mean recvd_out_comm

**% of HHs helped other households OUTSIDE their community in the past 12 months

forvalues i=1/5{
gen H109r_`i'=H109_`i'
recode H109r_`i' (8=4) (9=5)
}

forvalues i=1/5{
gen helped_out_comm`i'=0 if response==1
recode helped_out_comm`i' (0=1) if H109r_1==`i' | H109r_2==`i' | H109r_3==`i' | H109r_4==`i' | H109r_5==`i'
}

egen helped_out_comm_sum=rowtotal(helped_out_comm1 helped_out_comm2) if response==1
gen helped_out_comm=helped_out_comm_sum
recode helped_out_comm (0=0) (1/2=1)


svy: mean helped_out_comm1 helped_out_comm2 helped_out_comm3 helped_out_comm4 helped_out_comm5, over (sample_type)
lincom [helped_out_comm1]Refugee - [helped_out_comm1]_subpop_2
lincom [helped_out_comm2]Refugee - [helped_out_comm2]_subpop_2
lincom [helped_out_comm3]Refugee - [helped_out_comm3]_subpop_2
lincom [helped_out_comm4]Refugee - [helped_out_comm4]_subpop_2
lincom [helped_out_comm5]Refugee - [helped_out_comm5]_subpop_2

svy: mean helped_out_comm1 helped_out_comm2 helped_out_comm3 helped_out_comm4 helped_out_comm5

svy: mean helped_out_comm, over (sample_type)
lincom [helped_out_comm]Refugee - [helped_out_comm]_subpop_2

svy: mean helped_out_comm


**Compared to one year ago, % of households reported their ability increased, decreased or stayed same to get help from anyone within or outside their community. 

/*
1	Increased
2	Remained same
3	Decreased
8	Don't know
9	Refused
*/

gen H104r=H104
recode H104r (8=4) (9=5)

forvalues i=1/5{
gen bond_bridge_status`i'=0 if response==1
recode bond_bridge_status`i' (0=1) if H104r==`i'
}

svy: mean bond_bridge_status1 bond_bridge_status2 bond_bridge_status3 bond_bridge_status4 bond_bridge_status5, over (sample_type)
lincom [bond_bridge_status1]Refugee - [bond_bridge_status1]_subpop_2
lincom [bond_bridge_status2]Refugee - [bond_bridge_status2]_subpop_2
lincom [bond_bridge_status3]Refugee - [bond_bridge_status3]_subpop_2
lincom [bond_bridge_status4]Refugee - [bond_bridge_status4]_subpop_2
lincom [bond_bridge_status5]Refugee - [bond_bridge_status5]_subpop_2

svy: mean bond_bridge_status1 bond_bridge_status2 bond_bridge_status3 bond_bridge_status4 bond_bridge_status5


**Linking Social Capital
/*
H111	Do you or does anyone else in your household has contact with any government officials?
H112	How do you (or another household member) start the link with the government officials? Through:
	1	A.Myself
	2	B.Family members or relatives
	3	C.Friend
	4	D.Neighbor
	5	E.By chance
	6	F.Other (specify)
	8	G.Don’t know
	9	H.Refused
H113	Could you ask the government officials to help your family or community if help was needed?

H114	Do you or does anyone else in your household have a contact with an NGO?
H115	How do you (or another household member) start contact with the NGO?  Through:
	1	A.Myself
	2	B.Family members or relatives
	3	C.Friend
	4	D.Neighbor
	5	E.By chance
	6	F.Other (specify)
	8	G.Don’t know
	9	H.Refused
H116	Could you ask the NGO to help your family or community if help was needed?
*/

gen link_1=0 if response==1
recode link_1 (0=1) if H111==1

forvalues i=1/8{
gen H112r_`i'=H112_`i'
recode H112r_`i' (8=7) (9=8)
}

forvalues i=1/8{
gen link2_`i'=0 if response==1
recode link2_`i' (0=1) if H112r_1==`i' | H112r_2==`i' | H112r_3==`i' | H112r_4==`i' | H112r_5==`i' | H112r_6==`i' | H112r_7==`i' | H112r_8==`i'
}

gen link_2=0 if response==1
recode link_2 (0=1) if link2_1==1 | link2_2==1

gen link_3=0 if response==1
recode link_3 (0=1) if H113==1

gen link_4=0 if response==1
recode link_4 (0=1) if H114==1

forvalues i=1/8{
gen H115r_`i'=H115_`i'
recode H115r_`i' (8=7) (9=8)
}

forvalues i=1/8{
gen link5_`i'=0 if response==1
recode link5_`i' (0=1) if H115r_1==`i' | H115r_2==`i' | H115r_3==`i' | H115r_4==`i' | H115r_5==`i' | H115r_6==`i' | H115r_7==`i' | H115r_8==`i'
}

gen link_5=0 if response==1
recode link_5 (0=1) if link5_1==1 | link5_2==1

gen link_6=0 if response==1
recode link_6 (0=1) if H116==1


svy: mean link_1, over (sample_type)
lincom [link_1]Refugee - [link_1]_subpop_2

svy: mean link_1

svy: mean link2_1 link2_2 link2_3 link2_4 link2_5 link2_6 link2_7 link2_8, over (sample_type)
lincom [link2_1]Refugee - [link2_1]_subpop_2
lincom [link2_2]Refugee - [link2_2]_subpop_2
lincom [link2_3]Refugee - [link2_3]_subpop_2
lincom [link2_4]Refugee - [link2_4]_subpop_2
lincom [link2_5]Refugee - [link2_5]_subpop_2
lincom [link2_6]Refugee - [link2_6]_subpop_2
lincom [link2_7]Refugee - [link2_7]_subpop_2
lincom [link2_8]Refugee - [link2_8]_subpop_2

svy: mean link2_1 link2_2 link2_3 link2_4 link2_5 link2_6 link2_7 link2_8

svy: mean link_2, over (sample_type)
lincom [link_2]Refugee - [link_2]_subpop_2

svy: mean link_2

svy: mean link_3, over (sample_type)
lincom [link_3]Refugee - [link_3]_subpop_2

svy: mean link_3

svy: mean link_4, over (sample_type)
lincom [link_4]Refugee - [link_4]_subpop_2

svy: mean link_4

svy: mean link_5, over (sample_type)
lincom [link_5]Refugee - [link_5]_subpop_2

svy: mean link_5


svy: mean link5_1 link5_2 link5_3 link5_4 link5_5 link5_6 link5_7 link5_8, over (sample_type)
lincom [link5_1]Refugee - [link5_1]_subpop_2
lincom [link5_2]Refugee - [link5_2]_subpop_2
lincom [link5_3]Refugee - [link5_3]_subpop_2
lincom [link5_4]Refugee - [link5_4]_subpop_2
lincom [link5_5]Refugee - [link5_5]_subpop_2
lincom [link5_6]Refugee - [link5_6]_subpop_2
lincom [link5_7]Refugee - [link5_7]_subpop_2
lincom [link5_8]Refugee - [link5_8]_subpop_2

svy: mean link5_1 link5_2 link5_3 link5_4 link5_5 link5_6 link5_7 link5_8

svy: mean link_6, over (sample_type)
lincom [link_6]Refugee - [link_6]_subpop_2

svy: mean link_6

egen linking_sum=rowtotal(link_1 link_2 link_3 link_4 link_5 link_6) if response==1

tab linking_sum

egen link_max=max(linking_sum)  
egen link_min=min(linking_sum) 

gen linking_index=(linking_sum-link_min)*100/(link_max-link_min) 

svy: mean linking_sum, over (sample_type)
lincom [linking_sum]Refugee - [linking_sum]_subpop_2

svy: mean linking_sum


svy: mean linking_index, over (sample_type)
lincom [linking_index]Refugee - [linking_index]_subpop_2

svy: mean linking_index

egen social_capital_score=rowtotal(bonding_sum bridge_sum linking_sum) if response==1  

egen social_capital_max=max(social_capital_score)  
egen social_capital_min=min(social_capital_score) 

gen social_capital_index=(social_capital_score-social_capital_min)*100/(social_capital_max-social_capital_min) 


svy: mean social_capital_score, over (sample_type)
lincom [social_capital_score]Refugee - [social_capital_score]_subpop_2

svy: mean social_capital_score


svy: mean social_capital_index, over (sample_type)
lincom [social_capital_index]Refugee - [social_capital_index]_subpop_2

svy: mean social_capital_index

***% of households think that the Misizi project were able to create enabling environment for peaceful coexistence between refugees and host communities


tab H117


gen H117r=0 if response==1
recode H117r (0=1) if H117==1

svy: mean H117r, over (sample_type)
lincom [H117r]Refugee - [H117r]_subpop_2

svy: mean H117r

**MODULE-I: SHOCKS EXPOSURE, IMPACTS OF COVID 19 SHOCKS AND COPING STRATEGIES

***In the last 12 months did your household experience any of the following shocks?

tab1 I101* //there are observations up to I101_14


/*
1	A.Too much rain/floods
2	B.Early/late rain
3	C.Too little rain/drought
4	D.Livestock disease
5	E.Corona Virus (COVID-19)
6	F.Crops attacked by pests/disease
7	G.Soil erosion/land slide
8	H.Fire/strong winds
9	I.Earthquake
10	J.Theft of HH valuable assets/cash
11	K.Conflict (including cattle, land raid)
12	L.Sharp food price increase
13	M.Sharp increase in agriculture/livestock inputs costs
14	N.Sharp drop in agriculture/livestock product prices
15	O.Death/illness of HH main income earner
16	P.Loss of work/labor
17	Q.Others (specify)
99	R.None
*/

forvalues i=1/18{
gen I101r_`i'=I101_`i'
recode I101r_`i'(99=18)
}


forvalues i=1/18{
gen shock_`i'=0 if response==1
recode shock_`i' (0=1) if I101r_1==`i' | I101r_2==`i' | I101r_3==`i' | I101r_4==`i' | I101r_5==`i' | I101r_6==`i' | I101r_7==`i' ///
						   | I101r_8==`i' | I101r_9==`i' | I101r_10==`i' | I101r_11==`i' | I101r_12==`i' | I101r_13==`i' | I101r_14==`i' ///
						    | I101r_15==`i' | I101r_16==`i' | I101r_17==`i' | I101r_18==`i'
}

tab1 shock_*

forvalues i=1/18{
svy: mean shock_`i', over(sample_type)
lincom [shock_`i']Refugee - [shock_`i']_subpop_2
}

svy: mean shock_1 shock_2 shock_3 shock_4 shock_5 shock_6 shock_7 shock_8 shock_9 shock_10 shock_11 shock_12 shock_13 shock_14 shock_15 ///
			shock_16 shock_17 shock_18, over(sample_type)
			
svy: mean shock_1 shock_2 shock_3 shock_4 shock_5 shock_6 shock_7 shock_8 shock_9 shock_10 shock_11 shock_12 shock_13 shock_14 shock_15 ///
			shock_16 shock_17 shock_18

egen shock_expose_sum=rowtotal(shock_1 - shock_17) if response==1
gen shock_expose=shock_expose_sum
recode shock_expose (0=0) (1/17=1)

tab shock_expose

svy: mean shock_expose, over(sample_type)
lincom [shock_expose]Refugee - [shock_expose]_subpop_2

svy: mean shock_expose

**% of HHs aware about Corona Virus

gen corona_virus=0 if response==1
recode corona_virus (0=1) if I102==1

svy: mean corona_virus, over(sample_type)
lincom [corona_virus]Refugee - [corona_virus]_subpop_2

svy: mean corona_virus


**% of HHs reported that their HHs was impacted for Corona Virus 

gen corona_virus_impact=0 if response==1
recode corona_virus_impact (0=1) if I103==1

svy: mean corona_virus_impact, over(sample_type)
lincom [corona_virus_impact]Refugee - [corona_virus_impact]_subpop_2

svy: mean corona_virus_impact


**% of HHs with impacts of COVID-19 in the past 12 months

/*
1	A.Loss of life
2	B.Loss of labor
3	C.Reduced income
4	D.Reduced supports from Govt./NGOs
5	E.Reduced mobility
6	F.Loss of livestock
7	G.Reduced social interactions with relatives and friends 
8	H.Loss of  HH assets (including distress sales)
9	I.Household member migrated
10	J.Household was displaced
11	K.Reduced ability to buy basic needs (e.g., food, cloth)
12	L.Huge medical cost for treatment of family members
13	M.Others (specify) 
99	N.Don’t know
88	O.Refused
*/


tab1 I104_* // observations available up to I104_5

forvalues i=1/15{
gen I104r_`i'=I104_`i'
recode I104r_`i' (99=14) (88=15)
}

forvalues i=1/15{
gen covid_imp`i'=0 if corona_virus_impact==1
recode covid_imp`i' (0=1) if I104r_1==`i' | I104r_2==`i' | I104r_3==`i' | I104r_4==`i' | I104r_5==`i'
}

tab1 covid_imp*

svy: mean covid_imp1 covid_imp2 covid_imp3 covid_imp4 covid_imp5 covid_imp6 covid_imp7 covid_imp8 covid_imp9 covid_imp10 covid_imp11 ///
			covid_imp12 covid_imp13 covid_imp14 covid_imp15, over(sample_type)
			
svy: mean covid_imp1 covid_imp2 covid_imp3 covid_imp4 covid_imp5 covid_imp6 covid_imp7 covid_imp8 covid_imp9 covid_imp10 covid_imp11 ///
			covid_imp12 covid_imp13 covid_imp14 covid_imp15
			
forvalues i=1/15{
svy: mean covid_imp`i', over(sample_type)
lincom [covid_imp`i']Refugee - [covid_imp`i']_subpop_2
}			

tabulate corona_virus_impact sample_type

**% of HHs with impacts of COVID-19 on household income

forvalues i=1/4{
gen covid_imp_incom`i'=0 if corona_virus_impact==1
recode covid_imp_incom`i' (0=1) if I105==`i'
}

forvalues i=1/4{
svy: mean covid_imp_incom`i', over(sample_type)
lincom [covid_imp_incom`i']Refugee - [covid_imp_incom`i']_subpop_2
svy: mean covid_imp_incom`i'
}	

**% of HHs with impacts of COVID-19 on household food consumption

forvalues i=1/4{
gen covid_imp_food`i'=0 if corona_virus_impact==1
recode covid_imp_food`i' (0=1) if I106==`i'
}


svy: mean covid_imp_food1 covid_imp_food2 covid_imp_food3 covid_imp_food4, over(sample_type)
svy: mean covid_imp_food1 covid_imp_food2 covid_imp_food3 covid_imp_food4

forvalues i=1/4{
svy: mean covid_imp_food`i', over(sample_type)
lincom [covid_imp_food`i']Refugee - [covid_imp_food`i']_subpop_2
}	


**% of HHs with coping strategies for the impacts of COVID-19

tab1 I107_* // obeservation available up to I107_6 


/*
1	A.Selling livestock
2	B.Selling agriculture food/seed stock
3	C.Slaughter livestock
4	D.Temporary Migration (only some family members) 
5	E.Temporary Migrate (the whole family) 
6	F.Permanent migration of some family member(s) 
7	G.Send boys to stay with relatives or other HH
8	H.Send girls to stay with relatives or other HH
9	I.Take children out of school
10	J.Reduce food consumption
11	K.Take up new wage labor
12	L.Sell household items (e.g., radio, bed) 
13	M.Sell productive assets (e.g., plough, water pump) 
14	N.Take out a loan from a money lender
15	O.Take out a loan from friends or relatives
16	P.Send children to work for money (e.g., domestic service) 
17	Q.Receive money or food from relatives within community
18	R.Receive money from a relative from  outside (remittance) 
19	S.Receive food aid or assistance from the government (including food/cash-for-work) 
20	T.Receive food aid or assistance from an NGO (including food/cash-for-work) 
21	U.Use money from savings
22	V.Receive help from local organizations/companies
23	W.Other (specify) 
24	X.No coping strategies
88	Y.Don’t Know
99	Z.Refused
*/

forvalues i=1/26{
gen I107r_`i'=I107_`i'
recode I107r_`i' (88=25) (99=26)
}


forvalues i=1/26{
gen covid_cope`i'=0 if corona_virus_impact==1
recode covid_cope`i' (0=1) if I107r_1==`i' | I107r_2==`i' | I107r_3==`i' | I107r_4==`i' | I107r_5==`i' | I107r_6==`i'
}

svy: mean covid_cope1 covid_cope2 covid_cope3 covid_cope4 covid_cope5 covid_cope6 covid_cope7 covid_cope8 covid_cope9 ///
          covid_cope10 covid_cope11 covid_cope12 covid_cope13 covid_cope14 covid_cope15 covid_cope16 covid_cope17 ///
		  covid_cope18 covid_cope19 covid_cope20 covid_cope21 covid_cope22 covid_cope23 covid_cope24 covid_cope25 covid_cope26, over(sample_type)

svy: mean covid_cope1 covid_cope2 covid_cope3 covid_cope4 covid_cope5 covid_cope6 covid_cope7 covid_cope8 covid_cope9 ///
          covid_cope10 covid_cope11 covid_cope12 covid_cope13 covid_cope14 covid_cope15 covid_cope16 covid_cope17 ///
		  covid_cope18 covid_cope19 covid_cope20 covid_cope21 covid_cope22 covid_cope23 covid_cope24 covid_cope25 covid_cope26


forvalues i=1/26{
svy: mean covid_cope`i', over(sample_type)
lincom [covid_cope`i']Refugee - [covid_cope`i']_subpop_2
}

***How is the quality of life for you and your household NOW, after having been experienced with the COVID 19 two years ago?

/*
1	Fully recovered and better than before the COVID-19
2	Fully recovered, same as before the COVID-19
3	Partially recovered
4	Have not recovered at all
5	Don’t know
*/

forvalues i=1/5{
gen quality_life_CVD19_`i'=0 if corona_virus_impact==1
recode quality_life_CVD19_`i' (0=1) if I108==`i'
}

svy: mean quality_life_CVD19_1 quality_life_CVD19_2 quality_life_CVD19_3 quality_life_CVD19_4 quality_life_CVD19_5, over(sample_type)
lincom [quality_life_CVD19_1]Refugee - [quality_life_CVD19_1]_subpop_2
lincom [quality_life_CVD19_2]Refugee - [quality_life_CVD19_2]_subpop_2
lincom [quality_life_CVD19_3]Refugee - [quality_life_CVD19_3]_subpop_2
lincom [quality_life_CVD19_4]Refugee - [quality_life_CVD19_4]_subpop_2
lincom [quality_life_CVD19_5]Refugee - [quality_life_CVD19_5]_subpop_2

svy: mean quality_life_CVD19_1 quality_life_CVD19_2 quality_life_CVD19_3 quality_life_CVD19_4 quality_life_CVD19_5

*% of households who were partially recovered or not recovered with the perception that they would be able to recover  

gen recovery_percep=0 if quality_life_CVD19_3==1 | quality_life_CVD19_4==1
recode recovery_percep (0=1) if I109==1

svy: mean recovery_percep, over(sample_type)
lincom [recovery_percep]Refugee - [recovery_percep]_subpop_2

svy: mean recovery_percep

tabulate corona_virus_impact sample_type if quality_life_CVD19_3==1 | quality_life_CVD19_4==1

tabulate recovery_percep sample_type

*% of households who reported that they will be able to recover with the duration of recovery  

/*
1	Six months
2	One year
3	More than one year
8	Don’t know
9	Refused
*/


gen I110r=I110
recode I110r (8=4) (9=5)

forvalues i=1/5{
gen revov_duration_`i'=0 if recovery_percep==1
recode revov_duration_`i' (0=1) if I110r==`i'
}

svy: mean revov_duration_1 revov_duration_2 revov_duration_3 revov_duration_4 revov_duration_5, over(sample_type)
lincom [revov_duration_1]Refugee - [revov_duration_1]_subpop_2
lincom [revov_duration_2]Refugee - [revov_duration_2]_subpop_2
lincom [revov_duration_3]Refugee - [revov_duration_3]_subpop_2
lincom [revov_duration_4]Refugee - [revov_duration_4]_subpop_2
lincom [revov_duration_5]Refugee - [revov_duration_5]_subpop_2

svy: mean revov_duration_1 revov_duration_2 revov_duration_3 revov_duration_4 revov_duration_5

***% of households received assistance for COVID-19 supports


gen rec_covid19_asst=0 if corona_virus==1
recode rec_covid19_asst (0=1) if I111==1

svy: mean rec_covid19_asst, over(sample_type)
lincom [rec_covid19_asst]Refugee - [rec_covid19_asst]_subpop_2

svy: mean rec_covid19_asst

tabulate rec_covid19_asst sample_type

**% of households with received assistance for COVID-19, by the sources of supports

forvalues i=1/10{
gen cvd19_asst_src_`i'=0 if rec_covid19_asst==1
recode cvd19_asst_src_`i' (0=1) if I112_1==`i' | I112_2==`i' | I112_3==`i' | I112_4==`i' | I112_5==`i' | I112_6==`i' ///
                                    | I112_7==`i' | I112_8==`i' | I112_9==`i' | I112_10==`i'
}

svy: mean cvd19_asst_src_1 cvd19_asst_src_2 cvd19_asst_src_3 cvd19_asst_src_4 cvd19_asst_src_5 cvd19_asst_src_6 cvd19_asst_src_7 ///
			cvd19_asst_src_8 cvd19_asst_src_9 cvd19_asst_src_10, over(sample_type)
lincom [cvd19_asst_src_1]Refugee - [cvd19_asst_src_1]_subpop_2
lincom [cvd19_asst_src_2]Refugee - [cvd19_asst_src_2]_subpop_2
lincom [cvd19_asst_src_3]Refugee - [cvd19_asst_src_3]_subpop_2
lincom [cvd19_asst_src_4]Refugee - [cvd19_asst_src_4]_subpop_2
lincom [cvd19_asst_src_5]Refugee - [cvd19_asst_src_5]_subpop_2
lincom [cvd19_asst_src_6]Refugee - [cvd19_asst_src_6]_subpop_2
lincom [cvd19_asst_src_7]Refugee - [cvd19_asst_src_7]_subpop_2
lincom [cvd19_asst_src_8]Refugee - [cvd19_asst_src_8]_subpop_2
lincom [cvd19_asst_src_9]Refugee - [cvd19_asst_src_9]_subpop_2
lincom [cvd19_asst_src_10]Refugee - [cvd19_asst_src_10]_subpop_2

svy: mean cvd19_asst_src_1 cvd19_asst_src_2 cvd19_asst_src_3 cvd19_asst_src_4 cvd19_asst_src_5 cvd19_asst_src_6 cvd19_asst_src_7 ///
			cvd19_asst_src_8 cvd19_asst_src_9 cvd19_asst_src_10
			

**MODULE-J: EMPLOYMENT

gen self_emply_agric=0 if response==1
recode self_emply_agric (0=1) if J101A_A==1

svy: mean self_emply_agric, over(sample_type)
lincom [self_emply_agric]Refugee - [self_emply_agric]_subpop_2

svy: mean self_emply_agric


tabulate self_emply_agric sample_type


gen selfemply_agric_freq1=0 if self_emply_agric==1
recode selfemply_agric_freq1 (0=1) if J101A_B==1
gen selfemply_agric_freq2=0 if self_emply_agric==1
recode selfemply_agric_freq2 (0=1) if J101A_B==2
gen selfemply_agric_freq3=0 if self_emply_agric==1
recode selfemply_agric_freq3 (0=1) if J101A_B==3


svy: mean selfemply_agric_freq1 selfemply_agric_freq2 selfemply_agric_freq3, over(sample_type)
lincom [selfemply_agric_freq1]Refugee - [selfemply_agric_freq1]_subpop_2
lincom [selfemply_agric_freq2]Refugee - [selfemply_agric_freq2]_subpop_2
lincom [selfemply_agric_freq3]Refugee - [selfemply_agric_freq3]_subpop_2

svy: mean selfemply_agric_freq1 selfemply_agric_freq2 selfemply_agric_freq3

tab J101A_C

gen selfemply_agric_pay1=0 if self_emply_agric==1
recode selfemply_agric_pay1 (0=1) if J101A_C==1
gen selfemply_agric_pay2=0 if self_emply_agric==1
recode selfemply_agric_pay2 (0=1) if J101A_C==2
gen selfemply_agric_pay3=0 if self_emply_agric==1
recode selfemply_agric_pay3 (0=1) if J101A_C==3

svy: mean selfemply_agric_pay1 selfemply_agric_pay2 selfemply_agric_pay3, over(sample_type)
lincom [selfemply_agric_pay1]Refugee - [selfemply_agric_pay1]_subpop_2
lincom [selfemply_agric_pay2]Refugee - [selfemply_agric_pay2]_subpop_2
lincom [selfemply_agric_pay3]Refugee - [selfemply_agric_pay3]_subpop_2
svy: mean selfemply_agric_pay1 selfemply_agric_pay2 selfemply_agric_pay3

**% employed others in self-employed agriculture

gen J102Ar=J102A
gen J102Br=J102B
gen J102Cr=J102C
gen J102Dr=J102D

recode J102Ar (2=0)
recode J102Br (2=0)
recode J102Cr (2=0)
recode J102Dr (2=0)

gen selfemply_agric_rmp_oth=0 if self_emply_agric==1
recode selfemply_agric_rmp_oth (0=1) if J102Ar==1 | J102Br==1 | J102Cr==1 | J102Dr==1

svy: mean selfemply_agric_rmp_oth, over(sample_type)
lincom [selfemply_agric_rmp_oth]Refugee - [selfemply_agric_rmp_oth]_subpop_2


svy: mean J102Ar J102Br J102Cr J102Dr, over(sample_type)
lincom [J102Ar]Refugee - [J102Ar]_subpop_2
lincom [J102Br]Refugee - [J102Br]_subpop_2
lincom [J102Cr]Refugee - [J102Cr]_subpop_2
lincom [J102Dr]Refugee - [J102Dr]_subpop_2


svy: mean J102Ar J102Br J102Cr J102Dr

**SELF-EMPLOYMENT (NON-AGRICULTURAL BUSINESS)

*% of HHs are self-employed in non-agricultural business

tab J103

gen J103r_1=J103
recode J103r_1 (2=0) (9=0)

gen J103r_2=J103
recode J103r_2 (1=0) (2=1) (9=0)

svy: mean J103r_1 J103r_2, over(sample_type)
lincom [J103r_1]Refugee - [J103r_1]_subpop_2
lincom [J103r_2]Refugee - [J103r_2]_subpop_2

svy: mean J103r_1 J103r_2

tabulate J103r_1 sample_type


**% with business been registered by the local or national government

forvalues i=1/4{
gen J104r_`i'=0 if J103r_1==1
}

recode J104r_1 (0=1) if J104==1
recode J104r_2 (0=1) if J104==2
recode J104r_3 (0=1) if J104==3
recode J104r_4 (0=1) if J104==9

svy: mean J104r_1 J104r_2 J104r_3 J104r_4, over(sample_type)
lincom [J104r_1]Refugee - [J104r_1]_subpop_2
lincom [J104r_2]Refugee - [J104r_2]_subpop_2
lincom [J104r_3]Refugee - [J104r_3]_subpop_2
lincom [J104r_4]Refugee - [J104r_4]_subpop_2

svy: mean J104r_1 J104r_2 J104r_3 J104r_4

tab J104

tab J106

svy: mean J106, over (sample_type)
lincom [J106]Refugee - [J106]_subpop_2

svy: mean J106

by sample_type, sort : summarize J106 [aweight = weight]

sum J106 [aweight = weight]

by sample_type, sort : centile J106 [aweight = weight]
by sample_type, sort : summarize J106 [aweight = weight], detail

sum J106 [aweight = weight], detail

**% employed others in self-employed non-agriculture business

gen J107Ar=J107A
gen J107Br=J107B
gen J107Cr=J107C
gen J107Dr=J107D

recode J107Ar (2=0)
recode J107Br (2=0)
recode J107Cr (2=0)
recode J107Dr (2=0)

gen selfemply_nagric_rmp_oth=0 if J103r_1==1
recode selfemply_nagric_rmp_oth (0=1) if J107Ar==1 | J107Br==1 | J107Cr==1 | J107Dr==1

svy: mean selfemply_nagric_rmp_oth, over(sample_type)
lincom [selfemply_nagric_rmp_oth]Refugee - [selfemply_nagric_rmp_oth]_subpop_2

svy: mean selfemply_nagric_rmp_oth

svy: mean J107Ar J107Br J107Cr J107Dr, over(sample_type)
lincom [J107Ar]Refugee - [J107Ar]_subpop_2
lincom [J107Br]Refugee - [J107Br]_subpop_2
lincom [J107Cr]Refugee - [J107Cr]_subpop_2
lincom [J107Dr]Refugee - [J107Dr]_subpop_2


svy: mean J107Ar J107Br J107Cr J107Dr


**WAGE EMPLOYMENT (NON-AGRICULTURAL)
**% of HHs with wage-employment


tab J108

gen J108r_1=J108
recode J108r_1 (2=0) (9=0)

gen J108r_2=J108
recode J108r_2 (1=0) (2=1) (9=0)

svy: mean J108r_1 J108r_2, over(sample_type)
lincom [J108r_1]Refugee - [J108r_1]_subpop_2
lincom [J108r_2]Refugee - [J108r_2]_subpop_2

svy: mean J108r_1 J108r_2

tabulate J108r_1 sample_type


gen wage_employ=0 if response==1
recode wage_employ (0=1) if J108==1 | J108==2


svy: mean wage_employ, over(sample_type)
lincom [wage_employ]Refugee - [wage_employ]_subpop_2

svy: mean wage_employ

tabulate 








