/***********************************************************
MISIZI MARSHLAND PROJECT PERFORMANCE EVALUATION 2022
************************************************************
HOUSEHOLD DEMOGRAPHIC ANALYSIS
************************************************************
Created by: Towfique Aziz, Sr. Advisor for M&E and Research
			towfique@tangointernational.com
			May 19, 2022
************************************************************/
************************************************************

cd "C:\Users\towfi\Dropbox (Tango International)\2021_UNHCR_IKEA_Rwanda\Quantitative\Data analysis"

use "Misizi_PE_11May2022_edited_working.dta", clear

tabulate ability_loc_hh sample_type

tabulate consent sample_type

tabulate response sample_type


svy: tabulate response sample_type, col

svy: mean response, over(sample_type)
lincom [response]Refugee - [response]_subpop_2

**Family size

tab1 AA104 hm_count

svy: mean hm_count, over(sample_type)
lincom [hm_count]Refugee - [hm_count]_subpop_2

svy: mean hm_count

***Sex of the HH head 

tab A104_1

gen sex_hhh=A104_1
recode sex_hhh (1=0) (2=1)

label define A104_1_lbl 1 "Female" 0 "Male"
label value sex_hhh A104_1_lbl

tab sex_hhh

svy: mean sex_hhh, over(sample_type)
lincom [sex_hhh]Refugee - [sex_hhh]_subpop_2

svy: mean sex_hhh

***Age of the HH Head

tab A103_1


svy: mean A103_1, over(sample_type)
lincom [A103_1]Refugee - [A103_1]_subpop_2

svy: mean A103_1

svy: mean A103_1 if sex_hhh==0, over(sample_type)
lincom [A103_1]Refugee - [A103_1]_subpop_2

svy: mean A103_1 if sex_hhh==0


svy: mean A103_1 if sex_hhh==1, over(sample_type)
lincom [A103_1]Refugee - [A103_1]_subpop_2

svy: mean A103_1 if sex_hhh==1


**Household Head age distribution

gen HHH_age1=0 if response==1
recode HHH_age1 (0=1) if A103_1>=10 & A103_1<15
gen HHH_age2=0 if response==1
recode HHH_age2 (0=1) if A103_1>=15 & A103_1<50
gen HHH_age3=0 if response==1
recode HHH_age3 (0=1) if A103_1>=50 & A103_1<65
gen HHH_age4=0 if response==1
recode HHH_age4 (0=1) if A103_1>=65

tab1 HHH_age*

svy: mean HHH_age1 HHH_age2 HHH_age3 HHH_age4, over(sample_type)
lincom [HHH_age1]Refugee - [HHH_age1]_subpop_2
lincom [HHH_age2]Refugee - [HHH_age2]_subpop_2
lincom [HHH_age3]Refugee - [HHH_age3]_subpop_2
lincom [HHH_age4]Refugee - [HHH_age4]_subpop_2

svy: mean HHH_age1 HHH_age2 HHH_age3 HHH_age4

**Household head education

forvalues i=1/11{
gen HHH_edu`i'=0 if response==1
}

recode HHH_edu1 (0=1) if A106_1==2 | A107_1==1

tab HHH_edu1

forvalues i=2/11{
recode HHH_edu`i' (0=1) if A107_1==`i'
}

tab1 HHH_edu*


svy: mean HHH_edu1 HHH_edu2 HHH_edu3 HHH_edu4 HHH_edu5 HHH_edu6 HHH_edu7 HHH_edu8 HHH_edu9 HHH_edu10 HHH_edu11, over(sample_type)
lincom [HHH_edu1]Refugee - [HHH_edu1]_subpop_2
lincom [HHH_edu2]Refugee - [HHH_edu2]_subpop_2
lincom [HHH_edu3]Refugee - [HHH_edu3]_subpop_2
lincom [HHH_edu4]Refugee - [HHH_edu4]_subpop_2
lincom [HHH_edu5]Refugee - [HHH_edu5]_subpop_2
lincom [HHH_edu6]Refugee - [HHH_edu6]_subpop_2
lincom [HHH_edu7]Refugee - [HHH_edu7]_subpop_2
lincom [HHH_edu8]Refugee - [HHH_edu8]_subpop_2
lincom [HHH_edu9]Refugee - [HHH_edu9]_subpop_2
lincom [HHH_edu10]Refugee - [HHH_edu10]_subpop_2
lincom [HHH_edu11]Refugee - [HHH_edu11]_subpop_2


svy: mean HHH_edu1 HHH_edu2 HHH_edu3 HHH_edu4 HHH_edu5 HHH_edu6 HHH_edu7 HHH_edu8 HHH_edu9 HHH_edu10 HHH_edu11


*Marital Status of HH Head

forvalues i=1/4{
gen hhh_marital_`i'=0 if response==1
recode hhh_marital_`i' (0=1) if A108_1==`i'
}

svy: mean hhh_marital_1 hhh_marital_2 hhh_marital_3 hhh_marital_4, over(sample_type)
lincom [hhh_marital_1]Refugee - [hhh_marital_1]_subpop_2
lincom [hhh_marital_2]Refugee - [hhh_marital_2]_subpop_2
lincom [hhh_marital_3]Refugee - [hhh_marital_3]_subpop_2
lincom [hhh_marital_4]Refugee - [hhh_marital_4]_subpop_2

svy: mean hhh_marital_1 hhh_marital_2 hhh_marital_3 hhh_marital_4

**Primary Occupation of HH Head

tab A109_1

forvalues i=1/8{
gen hhh_occup_`i'=0 if response==1
recode hhh_occup_`i' (0=1) if A109_1==`i'
}

svy: mean hhh_occup_1 hhh_occup_2 hhh_occup_3 hhh_occup_4 hhh_occup_5 hhh_occup_6 hhh_occup_7 hhh_occup_8, over(sample_type)
lincom [hhh_occup_1]Refugee - [hhh_occup_1]_subpop_2
lincom [hhh_occup_2]Refugee - [hhh_occup_2]_subpop_2
lincom [hhh_occup_3]Refugee - [hhh_occup_3]_subpop_2
lincom [hhh_occup_4]Refugee - [hhh_occup_4]_subpop_2
lincom [hhh_occup_5]Refugee - [hhh_occup_5]_subpop_2
lincom [hhh_occup_6]Refugee - [hhh_occup_6]_subpop_2
lincom [hhh_occup_7]Refugee - [hhh_occup_7]_subpop_2
lincom [hhh_occup_8]Refugee - [hhh_occup_8]_subpop_2

svy: mean hhh_occup_1 hhh_occup_2 hhh_occup_3 hhh_occup_4 hhh_occup_5 hhh_occup_6 hhh_occup_7 hhh_occup_8

**Disability of HH head

/*
1	A.None
2	B.Sensory disability
3	C.Physical disability
4	D.Mental disability
5	E.Chronic illness
8	F.Don’t know 
9	G.Refused
*/

tab1 A110_1_*

forvalues i=1/7{
gen A110r_`i'_1=A110_`i'_1
recode A110r_`i'_1 (8=6) (9=7)
}

forvalues i=1/7{
gen hhh_dis_`i'=0 if response==1
recode hhh_dis_`i' (0=1) if A110r_1_1==`i' | A110r_2_1==`i' | A110r_3_1==`i' | A110r_4_1==`i' | A110r_5_1==`i' | A110r_6_1==`i' | A110r_7_1==`i'
}

svy: mean hhh_dis_1 hhh_dis_2 hhh_dis_3 hhh_dis_4 hhh_dis_5 hhh_dis_6 hhh_dis_7, over(sample_type)
lincom [hhh_dis_1]Refugee - [hhh_dis_1]_subpop_2
lincom [hhh_dis_2]Refugee - [hhh_dis_2]_subpop_2
lincom [hhh_dis_3]Refugee - [hhh_dis_3]_subpop_2
lincom [hhh_dis_4]Refugee - [hhh_dis_4]_subpop_2
lincom [hhh_dis_5]Refugee - [hhh_dis_5]_subpop_2
lincom [hhh_dis_6]Refugee - [hhh_dis_6]_subpop_2
lincom [hhh_dis_7]Refugee - [hhh_dis_7]_subpop_2

svy: mean hhh_dis_1 hhh_dis_2 hhh_dis_3 hhh_dis_4 hhh_dis_5 hhh_dis_6 hhh_dis_7


**% of household heads are project participants

tab A111_1

gen A111r_1=A111_1
recode A111r_1 (2=0)

svy: mean A111r_1, over(sample_type)
lincom [A111r_1]Refugee - [A111r_1]_subpop_2

svy: mean A111r_1


**% of households with more than one household members are project benefciaries

forvalues i=2/13{
gen A111r_`i'=A111_`i'
recode A111r_`i' (2=0)
}

egen A111r_sum=rowtotal(A111r_1 - A111r_13) if response==1
gen A111r=A111r_sum
recode A111r (0/1=0) (2/3=1)

svy: mean A111r, over(sample_type)
lincom [A111r]Refugee - [A111r]_subpop_2

svy: mean A111r

****Household member's age
/*
0-4
5-9
10-14
15-19
20-24
25-29
30-34
35-39
40-44
45-49
50-54
55-59
60-64
65-69
70-74
75-79
80-84
85+
*/


keep SubmissionDate	start_time end_time tab_date tab_id	date sample_type block_village sample_id response weight sex_hhh KEY mem* ///
	A102_* A103_* A104_* A105_Head*	A105_*	A106_* A107_* A108_* A109_*	A110* A111_* A112_*

	 
drop A105_others* A109_others*  

rename A102_* A102*
rename A103_* A103*
rename A104_*  A104* 
rename A105_Head*  A105Head* 
rename A105_*  A105* 
rename A106_*  A106* 
rename A107_*  A107* 
rename A108_*  A108* 
rename A109_*  A109* 
rename A110_1_*  A1101* 
rename A110_2_*  A1102* 
rename A110_3_*  A1103* 
rename A110_4_*  A1104* 
rename A110_5_*  A1105*
rename A110_6_*  A1106* 
rename A110_7_*  A1107*
rename A111_*  A111* 
rename A112_*  A112* 

gen id=sample_id

reshape long mem A102 A103 A104 A105Head A105 A106 A107 A108 A109 A1101 A1102 A1103 A1104 A1105 A1106 A1107 A111 A112, i(id) j(hh_mem)

keep if mem!=.

save "Misizi_PE_roster.dta"


cd "C:\Users\towfi\Dropbox (Tango International)\2021_UNHCR_IKEA_Rwanda\Quantitative\Data analysis"

use "Misizi_PE_roster.dta", clear


svyset block_village [pw=weight], strata(sample_type)

***Household member by age and sex

gen hhm_age_cat=.
replace hhm_age_cat=1 if A103<5
replace hhm_age_cat=2 if (A103>4 & A103<10)
replace hhm_age_cat=3 if (A103>9 & A103<15)
replace hhm_age_cat=4 if (A103>14 & A103<20)
replace hhm_age_cat=5 if (A103>19 & A103<25)
replace hhm_age_cat=6 if (A103>24 & A103<30)
replace hhm_age_cat=7 if (A103>29 & A103<35)
replace hhm_age_cat=8 if (A103>34 & A103<40)
replace hhm_age_cat=9 if (A103>39 & A103<45)
replace hhm_age_cat=10 if (A103>44 & A103<50)
replace hhm_age_cat=11 if (A103>49 & A103<55)
replace hhm_age_cat=12 if (A103>54 & A103<60)
replace hhm_age_cat=13 if (A103>59 & A103<65)
replace hhm_age_cat=14 if (A103>64 & A103<70)
replace hhm_age_cat=15 if (A103>69 & A103<75)
replace hhm_age_cat=16 if (A103>74 & A103<80)
replace hhm_age_cat=17 if (A103>79 & A103<85)
replace hhm_age_cat=18 if A103>84

label define hhm_age_cat1 1 "0-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8 "35-39" 9 "40-44" ///
                            10 "45-49" 11 "50-54" 12 "55-59" 13 "60-64" 14 "65-69" 15 "70-74" 16 "75-79" 17 "80-84" 18 "85+"
label value hhm_age_cat hhm_age_cat1


forvalues i=1/18{
gen age_cat_`i'=0
recode age_cat_`i' (0=1) if hhm_age_cat==`i'
}

svy: mean age_cat_1 age_cat_2 age_cat_3 age_cat_4 age_cat_5 age_cat_6 age_cat_7 age_cat_8 age_cat_9 age_cat_10 ///
          age_cat_11 age_cat_12 age_cat_13 age_cat_14 age_cat_15 age_cat_16 age_cat_17 age_cat_18, over(sample_type)
		  
svy: mean age_cat_1 age_cat_2 age_cat_3 age_cat_4 age_cat_5 age_cat_6 age_cat_7 age_cat_8 age_cat_9 age_cat_10 ///
          age_cat_11 age_cat_12 age_cat_13 age_cat_14 age_cat_15 age_cat_16 age_cat_17 age_cat_18	  
		  
		  
**Sex of the household members

gen hh_mem_male=0
recode 	hh_mem_male (0=1) if A104==1
gen hh_mem_female=0
recode 	hh_mem_female (0=1) if A104==2	 
gen hh_mem_oth=0
recode 	hh_mem_oth (0=1) if A104==3	
 

svy: mean hh_mem_male hh_mem_female hh_mem_oth, over(sample_type)
lincom [hh_mem_male]Refugee - [hh_mem_male]_subpop_2
lincom [hh_mem_female]Refugee - [hh_mem_female]_subpop_2
lincom [hh_mem_oth]Refugee - [hh_mem_oth]_subpop_2

svy: mean hh_mem_male hh_mem_female hh_mem_oth

total hh_mem_male if sample_type==1 
total hh_mem_male if sample_type==2

total hh_mem_female if sample_type==1 
total hh_mem_female if sample_type==2
		  
		  
		  
